<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Main Menu /////////////////////////
// Buttons:
define('MAIN_MENU_CONTENT_HEADING', "SISU");
define('MAIN_MENU_EDIT_PAGE_BTN', "Edit sisu");
define('MAIN_MENU_CREATE_PAGE_BTN', "Loo Page");
define('MAIN_MENU_MANAGE_BORDER_AREAS_BTN', "Manage Piirialade");
define('MAIN_MENU_MANAGE_IMAGES_BTN', "hallata pilte");
define('MAIN_MENU_PREVIEW_SITE_BTN', "Eelvaade Avaldatud Site");
define('MAIN_MENU_EDIT_BLOG_BTN', "Manage | Edit Blogi");
define('MAIN_MENU_EDIT_FILE_BTN', "Muuda faili");
define('MAIN_MENU_MENUS_HEADING', "MENUS");
define('MAIN_MENU_EDIT_MENUS_BTN', "Edit menüüd");
define('MAIN_MENU_MANAGE_MENUS_BTN', "Manage Menüü Ülesanded");
define('MAIN_MENU_EDIT_CSS_MENU_PARAMS_BTN', "Edit CSS-menüü parameetrid");
define('MAIN_MENU_EDIT_CSS_MENU_STYLES_BTN', "Edit CSS-menüü stiilid");
define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN', "Edit JS-menüü parameetrid");
define('MAIN_MENU_EDIT_JS_MENU_PARAMS_BTN_ALT', "Edit JavaScript-menüü parameetrid");
define('MAIN_MENU_EDIT_JS_MENU_STYLES_BTN', "Edit JS-menüü stiilid");
define('MAIN_MENU_EDIT_JS_MENU_STYLES_BTN_ALT', "Edit JavaScript-menüü stiilid");
define('MAIN_MENU_STYLES_HEAD_CONTENT_HEADING', "Stiil ja PEA SISU");
define('MAIN_MENU_STYLES_HEAD_CONTENT_HEADING_ALT', "Stiil ja pea SISU");
define('MAIN_MENU_EDIT_STYLES_BTN', "Edit Styles");
define('MAIN_MENU_EDIT_HEAD_BTN', "Edit Head kood");
define('MAIN_MENU_MANAGE_HEAD_BTN', "Manage Head kood");
define('MAIN_MENU_EDIT_FAVICON_BTN', "Edit Favicon");
define('MAIN_MENU_PAGE_MANAGEMENT_HEADING', "PAGE MANAGEMENT");
define('MAIN_MENU_EDIT_PAGE_TITLES_BTN', "Muuda pealkirjas");
define('MAIN_MENU_EDIT_META_TAGS_BTN', "Edit Meta Tags");
define('MAIN_MENU_DELETE_PAGE_BTN', "Kustuta lehekülg või Blogi");
define('MAIN_MENU_COPY_RENAME_BTN', "Kopeeri või Nimeta Lehekülgede");
define('MAIN_MENU_RESTORE_BTN', "Restore Page");
define('MAIN_MENU_ADD_PLUGIN_TO_PAGE_BTN', "Install Plugin Into Page");
define('MAIN_MENU_MANAGE_PAGE_ACCESS_BTN', "Manage Page Access");
define('MAIN_MENU_MANAGE_PAGE_ATTRIBUTES', "Manage lehekülje atribuudid");
define('MAIN_MENU_SITE_MANAGEMENT_HEADING', "Saidihalduse");
define('MAIN_MENU_RERUN_WIZARD_BTN', "Re juhitud Wizard");
define('MAIN_MENU_UPLOAD_TEMPLATE_BTN', "Laadi mall");
define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN', "Kasutajate haldamine ja Site valikud");
define('MAIN_MENU_MANAGE_USERS_SITE_OPTIONS_BTN_ALT', "Kasutajate haldamine ja saidi valikud");
define('MAIN_MENU_NEW_SESSION_BTN', "uus seanss");
define('MAIN_MENU_LOGOUT_BTN', "LOGI VÄLJA");
// Console Text:
define('MAIN_MENU_HEADER_DIVIDER', "BREEZE kodulehel hoone MOODUL");
// JavaScript Constants
define('MAIN_MENU_TIMEOUT_ERR', "Teie sessioon on aegunud. Kas soovite sisse logida?");

///////////////////////// Login /////////////////////////
// Buttons:
define('LOGIN_LOGIN_BTN', "Logi sisse");
// Console Text:
define('LOGIN_USERID_PASS_MSG', "Palun sisestage oma kasutajatunnus ja parool");
define('LOGIN_SAVE_LOGIN_MSG', "Salvesta logi sisse");
define('LOGIN_FORGOT_PASSWORD_MSG', "Unustasid salasõna?");
define('LOGIN_JS_WARNING_MSG', "HOIATUS: JavaScript peab olema lubatud, et kasutada seda süsteemi. Palun lülitage JavaScipt brauseris.");
define('LOGIN_ENTER_EMAIL_MSG', "Palun sisesta oma e-posti salasõna");
define('LOGIN_CAPTCHA_MSG', "Sisestage nimi või tähemärgid, mida näed <br /> Ülaltoodud pildil <span class='small_message'>(tõstutundlik)</span>");
// Popup Messages:
define('LOGIN_CAPTCHA_ERR', "Teie CAPTCHA kanne on ebaõige. Palun proovi uuesti.");
define('LOGIN_BAD_EMAIL_ERR', "E-posti aadress Sisestatud ei kehti. Palun kirjutage oma e-posti aadress uuesti.");
define('LOGIN_BAD_REFERER_ERR', "Sa ei paista olevat korralik.");
define('LOGIN_BAD_USER_ERR', "Ei ole kasutajat ei leitud e-posti. Palun sisesta uuesti oma e-posti aadress.");
define('LOGIN_PASSWORD_RESET_ERR', "Uus parool on saadetud e-posti. Palun kontrollige oma e-posti sõnum. Kui sa ei leia soovitud sõnum, vaadake spambox.");
define('LOGIN_DEFAULT_ERR', "Kummaline tõrge. Palun kontrollige päikese rakette.");
define('LOGIN_SSL_WARNING_1', "Märkus: oma brauseri salvestada parooli, siis on vaja saata see krüpteerimata seekord. Et seda probleemi vältida, proovige kasutada SSL turvaline ühendus (");
define('LOGIN_SSL_WARNING_2', "). Kindlasti rääkige oma brauseri salvestada / uuenda oma parooli pärast sisselogimist.");
define('LOGIN_EXCEEDED_MAX_ATTEMPTS', "Olete ületanud maksimaalse arvu Sisselogimiskatsete. Palun pöörduge oma süsteemiadministraatori poole.");
define('LOGIN_NO_USER_FOUND_ERR', "Ei ole sellise nimega kasutajat. Palun uuesti entre oma kasutajatunnus ja parool.");
define('LOGIN_NO_USER_FOUND_1_ERR', "Ei ole sellise nimega kasutajat.");
define('LOGIN_NO_USER_FOUND_2_ERR', "uuesti sisestama oma kasutajanime ja parooli.");
define('LOGIN_PASSWORD_NOT_CONFIRMED_MSG', "Teie parooli ei ole kinnitust leidnud. Palun sisesta uuesti oma salasõna.");
define('LOGIN_PASSWORD_NOT_CONFIRMED_1_MSG', "Teie parooli ei ole kinnitust leidnud.");
define('LOGIN_PASSWORD_NOT_CONFIRMED_2_MSG', "uuesti parooli sisestama.");

///////////////////////// Version /////////////////////////
// Console Text:
define('VERSION_DB_PROGRAM_FILE_MISMATCH_MSG', "Teie andmebaasist-revision-plaaster tasandil ei sobi teie programm-faile-redaktsioonis. Palun pöörduge oma süsteemiadministraatori poole.");
define('VERSION_PROGRAM_FILES_VERSION_MSG', "Program Files redaktsioonitasemega");
define('VERSION_DB_VERSION_MSG', "Andmebaas Patch Level");

///////////////////////// Dashboard /////////////////////////
// Console Text:
define('WELCOME_1_MSG', "Tere tulemast");
define('WELCOME_2_MSG', "kuni Breeze Website Builder ™. Vajuta ükskõik menüü rubriigid vasakul juurdepääsu süsteemi tööriistu hoone oma veebilehel.");
define('WELCOME_INSTALL_FOLDER_PRESENT_1_WARNING', "<b>HOIATUS !!!</b> Teie installikaustas on endiselt olemas serveris. Teie saidi võib kergesti kahjustada. Palun kliki");
define('WELCOME_INSTALL_FOLDER_PRESENT_2_WARNING', "siin");
define('WELCOME_INSTALL_FOLDER_PRESENT_3_WARNING', "kustutada <b><em>paigaldada</em></b> ja <b><em>SQL</em></b> kaustu serveris.");
define('WELCOME_LATEST_VERSION_INSTALLED_MSG', "Viimane versioon Breeze Website Builder ™ on paigaldatud");
define('WELCOME_BETA_VERSION_INSTALLED_1_MSG', "Sinu jooksev beetaversiooni");
define('WELCOME_BETA_VERSION_INSTALLED_2_MSG', "Breeze Website Builder ™. Praegune stabiilne versioon");
define('WELCOME_OLD_VERSION_INSTALLED_1_MSG', "versioon");
define('WELCOME_OLD_VERSION_INSTALLED_2_MSG', "Breeze Website Builder ™ on paigaldatud. Viimane versioon on");
define('WELCOME_OLD_VERSION_INSTALLED_3_MSG', "Click");
define('WELCOME_OLD_VERSION_INSTALLED_5_MSG', "alla laadida kõik hilisem versioon <br /> uuenduse faili kui teie praegune versioon. Märkus: Teil on vaja paigaldada kõik need uuendused järjest, kuni installimine on up-to-date.");
define('WELCOME_OLD_VERSION_INSTALLED_5A_MSG', "alla laadida uusima versiooni uuendada faili.");
define('WELCOME_OLD_VERSION_INSTALLED_6_MSG', "Pärast allalaadimist uuendused käsku");
define('WELCOME_OLD_VERSION_INSTALLED_6A_MSG', "Pärast allalaadimist update nuppu");
define('WELCOME_OLD_VERSION_INSTALLED_7_MSG', "siin");
define('WELCOME_OLD_VERSION_INSTALLED_8_MSG', "paigaldada järgmine uuendus.");
define('WELCOME_OLD_VERSION_INSTALLED_8A_MSG', "seda installida.");
define('WELCOME_OLD_VERSION_INSTALLED_9_MSG', "Pead olema sisse logitud administraatorina värskenduse installimiseks. Võtke ühendust oma süsteemi administraatoriga uuendada oma süsteemi.");
define('WELCOME_UNKNOWN_VERSION_INSTALLED_1_MSG', "versioon");
define('WELCOME_UNKNOWN_VERSION_INSTALLED_2_MSG', "Breeze Website Builder ™ on paigaldatud. <span class='extra_small_message'><br /> Märkus: Me ei saa võrrelda oma versiooni uusima versiooni, sest PHP direktiiv <b><i>allow_url_fopen</i></b> on välja lülitatud. Selleks, et seda armatuurlauale kontrollida oma versiooni ja annab teile linke uuendused, mida on vaja, et määrata <b><i>allow_url_fopen</i></b> <b><i>1</i></b> oma <b><i>php.ini</i></b> faili.</span>");
define('WELCOME_PAGE_COUNT', "Lehtede arv:");
define('WELCOME_BLOG_COUNT', "Blogi count:");
define('WELCOME_PLEASE_WAIT_DOWNLOADING_UPDATES_MSG', "Palun oota. Uuenduste allalaadimine ... See võib võtta mitu minutit.");

///////////////////////// Edit Page Select /////////////////////////
// Buttons:
define('EDIT_PAGE_SELECT_HEADING', "Edit sisu");
// Console Text:
define('EDIT_PAGE_SELECT_OPTIONS_HEADING', "toimetaja valikud");
define('EDIT_PAGE_SELECT_SOURCE_VIEW_OPTION', "Ava Allikas Vaata");
define('EDIT_PAGE_SELECT_MOBILE_STYLE_OPTION', "Mobiil Styles");
define('EDIT_PAGE_SELECT_SITE_STYLES_HEADING', "Saidi Styles");
define('EDIT_PAGE_SELECT_PAGE_DEFAULT_STYLES_OPTION', "Kasuta Page Vaikimisi");
define('EDIT_PAGE_SELECT_SITE_DEFAULT_STYLES_OPTION', "Kasutage Saidi Styles");
define('EDIT_PAGE_SELECT_DISABLE_SITE_STYLES_OPTION', "Keela Saidi Styles");

/////////////// HTML/JavaScript/PHP/CSS Editor Pages /////////////////
// Buttons:
define('EDITOR_PREVIEW', "Eelvaade");
define('EDITOR_SAVE', "Salvesta");
define('EDITOR_SAVE_AS', "Salvesta kui");
define('EDITOR_PUBLISH', "Avaldage");
define('EDITOR_REVERT', "tagasi pöörduma");
define('EDITOR_DELETE', "kustutama");
define('EDITOR_SEE_SITE', "Vaata Site");
define('EDITOR_SEE_FILE', "Vaata Fail");
define('EDITOR_CLEAR', "selge");
define('EDITOR_OPTIMIZE_IMAGES', "optimeerida pilte");
define('EDITOR_RESET_IMAGES', "Eemalda kõik pildid");
define('EDITOR_EDIT_STYLES', "Edit Styles");
// Console Text:
define('EDITOR_PAGE_NAME', "Lehekülje nimi");
define('EDITOR_FILE_NAME', "Faili nimi");
define('EDITOR_HEAD_NAME', "Head Nimi");
define('EDITOR_STYLE_SHEET', "Style Sheet");
// Popup Messages:
define('EDITOR_STARTING_UPDATE_MSG', "Alustades uuendus ...");
define('EDITOR_PREPARING_PREVIEW_MSG', "Ettevalmistused eelvaate ...");
define('EDITOR_REVERT_BLOG_CONFIRM_1_MSG', "Kas teie kindel, et tahad tagasi <b>blogi id</b>");
define('EDITOR_REVERT_BLOG_CONFIRM_2_MSG', "?");
define('EDITOR_REVERT_AREA_CONFIRM_1_MSG', "Oled kindel, et soovite pöörata tagasi");
define('EDITOR_REVERT_AREA_CONFIRM_2_MSG', "valdkonnas?");
define('EDITOR_REVERT_PAGE_CONFIRM_1_MSG', "Oled kindel, et soovite pöörata tagasi");
define('EDITOR_REVERT_PAGE_CONFIRM_2_MSG', "leheküljel?");
define('EDITOR_REVERT_FILE_CONFIRM_1_MSG', "Oled kindel, et soovite pöörata tagasi");
define('EDITOR_REVERT_FILE_CONFIRM_2_MSG', "faili?");
define('EDITOR_REVERT_HEAD_CONFIRM_1_MSG', "Oled kindel, et soovite pöörata tagasi");
define('EDITOR_REVERT_HEAD_CONFIRM_2_MSG', "pea?");
define('EDITOR_REVERT_CSS_CONFIRM_1_MSG', "Oled kindel, et soovite pöörata tagasi");
define('EDITOR_REVERT_CSS_CONFIRM_2_MSG', "css?");
define('EDITOR_REVERTING_MSG', "Tagasimuutumine viimati avaldatud versiooni ...");
define('EDITOR_REVERT_COMPLETE_MSG', "Taasta lõpetatud");
define('EDITOR_PAGE_NOT_SAVED_MSG', "Teie lehel ei salvestata. Kas soovid muudatused salvestada?");
define('EDITOR_FILE_NOT_SAVED_MSG', "Fail ei salvestata. Kas soovid muudatused salvestada?");
define('EDITOR_HEAD_NOT_SAVED_MSG', "Oma peaga ei salvestata. Kas soovid muudatused salvestada?");
define('EDITOR_CSS_NOT_SAVED_MSG', "Teie CSS ei salvestata. Kas soovid muudatused salvestada?");
define('EDITOR_PAGE_BLANK_ERR', "Page nimi ei saa olla tühi. Palun sisesta lehe nime ja proovi uuesti.");
define('EDITOR_FILE_BLANK_ERR', "Faili nimi ei saa olla tühi. Palun sisesta faili nimi ja proovige uuesti.");
define('EDITOR_FOLDER_BLANK_ERR', "Kausta nimi ei saa olla tühi. Palun sisesta kausta nimi ja proovige uuesti.");
define('EDITOR_HEAD_BLANK_ERR', "Head nimi ei saa olla tühi. Palun sisesta pea nime ja proovi uuesti.");
define('EDITOR_PAGE_ALREADY_EXISTS_1_ERR', "lehekülg");
define('EDITOR_PAGE_ALREADY_EXISTS_2_ERR', "juba eksisteerib. Palun mine tagasi peamenüüsse kopeerida ja ümber oma lehekülgedel.");
define('EDITOR_AREA_ALREADY_EXISTS_1_ERR', "piirialal");
define('EDITOR_AREA_ALREADY_EXISTS_2_ERR', "juba eksisteerib. Palun mine tagasi peamenüüsse hallata piirialadel.");
define('EDITOR_FILE_ALREADY_EXISTS_1_ERR', "fail");
define('EDITOR_FILE_ALREADY_EXISTS_2_ERR', "juba eksisteerib. Palun mine tagasi peamenüüsse kopeerida ja failide uuesti.");
define('EDITOR_FOLDER_ALREADY_EXISTS_1_ERR', "Kaust");
define('EDITOR_FOLDER_ALREADY_EXISTS_2_ERR', "juba eksisteerib.");
define('EDITOR_ERROR_CREATING_FOLDER_ERR', "Viga: Ei saa luua kataloogi.");
define('EDITOR_HEAD_ALREADY_EXISTS_1_ERR', "pea");
define('EDITOR_HEAD_ALREADY_EXISTS_2_ERR', "juba eksisteerib. Palun mine tagasi peamenüüsse kopeerida ja ümber oma pead.");
define('EDITOR_DELETE_BLOG_CONFIRM_1_MSG', "Olete kindel, et soovite kustutada <b>blogi id</b>");
define('EDITOR_DELETE_BLOG_CONFIRM_2_MSG', "?");
define('EDITOR_DELETE_AREA_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
define('EDITOR_DELETE_AREA_CONFIRM_2_MSG', "valdkonnas?");
define('EDITOR_DELETE_PAGE_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
define('EDITOR_DELETE_PAGE_CONFIRM_2_MSG', "leheküljel?");
define('EDITOR_DELETE_FILE_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
define('EDITOR_DELETE_FILE_CONFIRM_2_MSG', "faili?");
define('EDITOR_DELETE_HEAD_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
define('EDITOR_DELETE_HEAD_CONFIRM_2_MSG', "pea?");


///////////////////////// Create Page Select /////////////////////////
// Buttons:
define('CREATE_PAGE_SELECT_HEADING', "Loo Page");
define('CREATE_PAGE_SELECT_ENTER_PAGE_NAME_BTN', "Sisesta nimi Page");
define('CREATE_PAGE_SELECT_ADD_PLUGIN_BTN', "Lisa Plugin");
define('CREATE_PAGE_SELECT_SELECT_LAYOUT_BTN', "Vali paigutus");
// Popup Messages:
define('CREATE_PAGE_SELECT_CREATING_A_PAGE', "Lehe loomine");
define('CREATE_PAGE_SELECT_SELECTING_PAGE_LAYOUT', "Valides Page Layout");
define('CREATE_PAGE_SELECT_HELPFUL_TIPS', "Kasulikke nõuandeid");

///////////////////////// Create Page Select /////////////////////////
// Console Text:
define('CREATE_PAGE_PAGE_NAME_BLANK_1_ERR', "Oops! Sa unustasid, et sisestada lehe nimi.");
define('CREATE_PAGE_PAGE_NAME_BLANK_2_ERR', "ja sisestage lehe nimi.");
define('CREATE_PAGE_PAGE_ALREADY_EXISTS_ERR', "siseneda erinevate lehe nime.");
define('CREATE_PAGE_DEFAULT_CONTENT', "Sisesta oma sisu siin.");

///////////////////////// Manage Border Area Select /////////////////////////
// Buttons:
define('EDIT_BORDER_AREA_SELECT_HEADING', "Edit Piirialade");
define('MANAGE_BORDER_AREA_HEADING', "Manage Piirialade");
define('MANAGE_BORDER_AREA_BTN', "Manage Custom Piirialade");

///////////////////////// Manage Border Areas /////////////////////////
// Buttons:
define('MANAGE_CUSTOM_BORDER_AREA_HEADING', "Manage Custom Piirialade");
// Console Text:
define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA', "Lisa piirialal");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGN_AREA', "Määra piirialalt Page");
define('MANAGE_CUSTOM_BORDER_AREA_RENAME_AREA', "Nimeta piirialal");
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA', "Kustuta piirialal");
define('MANAGE_CUSTOM_BORDER_AREA_RENAME_AREA_SELECT', "Vali piirialal ümber");
define('MANAGE_CUSTOM_BORDER_AREA_NEW_NAME', "uus nimi");
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_SELECT', "Vali piirialal kustutada");
// Popup Messages:
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
define('MANAGE_CUSTOM_BORDER_AREA_DELETE_AREA_CONFIRM_2_MSG', "valdkonnas?");
define('MANAGE_CUSTOM_BORDER_AREA_DELETED_1_MSG', "Piirialal");
define('MANAGE_CUSTOM_BORDER_AREA_DELETED_2_MSG', "on välja jäetud.");
define('MANAGE_CUSTOM_BORDER_AREA_DELETED_ERR', "Viga: Ei saa lisada piirialal");
define('MANAGE_CUSTOM_BORDER_AREA_NOT_FOUND_1_ERR', "ei eksisteeri.");
define('MANAGE_CUSTOM_BORDER_AREA_NOT_FOUND_2_ERR', "naasta ala loovutamise leht.");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_MSG', "Piirialadel on uuesti määratud");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_MSG', "lehel.");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_ERR', "Viga: Ei saa määrata piirialadel kuni");
define('MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_ERR', "lehel.");
define('MANAGE_CUSTOM_BORDER_AREA_NO_AREAS_FOUND_ERR', "Viga: piirialadel leitud.");
define('MANAGE_CUSTOM_BORDER_AREA_ADDED_1_MSG', "Piirialal");
define('MANAGE_CUSTOM_BORDER_AREA_ADDED_2_MSG', "on lisatud.");
define('MANAGE_CUSTOM_BORDER_AREA_ADDED_ERR', "Viga: Ei saa lisada piirialal");
define('MANAGE_CUSTOM_BORDER_AREA_RENAMED_MSG', "on ümber nimetatud");
define('MANAGE_CUSTOM_BORDER_AREA_RENAMED_ERR', "Viga: Ei saa ümber nimetada");
define('MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_1_ERR', "Ei saa määrata piirialadel kuni");
define('MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_3_ERR', "lehele, sest nad on juba määratud.");

///////////////////////// Edit Blog Select /////////////////////////
// Buttons:
define('EDIT_BLOG_SELECT_CREATE_HEADING', "Loo Blog Page");
define('EDIT_BLOG_SELECT_EDIT_HEADING', "Edit Post");

///////////////////////// Edit File Select /////////////////////////
// Buttons:
define('EDIT_FILE_SELECT_HEADING', "Muuda faili");
define('EDIT_FILE_SELECT_PAGE_FILES_BTN', "Edit Page faile");
define('EDIT_FILE_SELECT_INCLUDE_SCRIPTS_BTN', "Muuda Siia skriptid");
define('EDIT_FILE_SELECT_LIB_MODULES_BTN', "Edit Raamatukogu moodulid");
// Console Text:
define('EDIT_FILE_SELECT_SELECT_FILE', "Valige File");
// Popup Messages:
define('EDIT_FILE_SELECT_NO_FOLDER_ERR', "Viga: ei määratud kaustas");

///////////////////////// Edit Menu Items /////////////////////////
// Buttons:
define('EDIT_MENU_ITEMS_HEADING', "Edit menüüd");
define('EDIT_MENU_ITEMS_UPDATE_ALL_BTN', "Värskenda kõik");
// Console Text:
define('EDIT_MENU_ITEMS_SELECT_MENU', "Vali menüüst lisada punkte");
define('EDIT_MENU_ITEMS_ITEM_TEXT', "Punkt tekst");
define('EDIT_MENU_ITEMS_NESTING_LEVEL', "pesastamistaset");
define('EDIT_MENU_ITEMS_URL', "URL");
define('EDIT_MENU_ITEMS_TARGET_WINDOW', "sihtakna");
define('EDIT_MENU_ITEMS_TOP_LEVEL', "Kõrgeim tase");
define('EDIT_MENU_ITEMS_1ST_SUB_LEVEL', "1. Sub Level");
define('EDIT_MENU_ITEMS_2ND_SUB_LEVEL', "2. Sub Level");
define('EDIT_MENU_ITEMS_3RD_SUB_LEVEL', "3. Sub Level");
define('EDIT_MENU_ITEMS_4TH_SUB_LEVEL', "4. Sub Level");
define('EDIT_MENU_ITEMS_5TH_SUB_LEVEL', "5. Sub Level");
define('EDIT_MENU_ITEMS_SELECT_MENU_MSG', "Palun valige menüü, et muuta menüü objektid.");
// Popup Messages:
define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
define('EDIT_MENU_ITEMS_DELETE_ITEM_CONFIRM_2_MSG', "menüüst?");
define('EDIT_MENU_ITEMS_STARTING_DELETE_MSG', "Alustades kustutada ...");
define('EDIT_MENU_ITEMS_LOCATING_MENU_ITEMS_MSG', "Asukoht menüü teemad ...");
define('EDIT_MENU_ITEMS_COULD_NOT_DELETE_ITEM_MSG', "Salvestusi ei leitud. Ei saa kustutada menüüst.");
define('EDIT_MENU_ITEMS_MENU_ITEM_DELETED_MSG', "Menüüvalik kustutatakse");
define('EDIT_MENU_ITEMS_DELETING_MENU_ITEM_MSG', "Kustutamine menüüst ...");
define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEM_MSG', "Kirjet ei leita. Ei saa uuendada menüüst.");
define('EDIT_MENU_ITEMS_MENU_ITEM_UPDATED_MSG', "Menüüvalik uuendatud");
define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEM_MSG', "Uuendamine menüüst ...");
define('EDIT_MENU_ITEMS_COULD_NOT_UPDATE_ITEMS_MSG', "Kirjet ei leita. Ei saa uuendada menüü objektid.");
define('EDIT_MENU_ITEMS_MENU_ITEMS_UPDATED_MSG', "Menüüelemente uuendatud");
define('EDIT_MENU_ITEMS_UPDATING_MENU_ITEMS_MSG', "Uuendamine menüü teemad ...");
define('EDIT_MENU_ITEMS_RETRIEVING_MENU_ITEMS_MSG', "Otsib menüü teemad ...");
define('EDIT_MENU_ITEMS_NOT_SAVED_CONFIRM_MSG', "Sinu muudatused pole veel salvestatud. Kas soovid muudatused salvestada naasid peamenüü?");

///////////////////////// Manage Menu Assignments /////////////////////////
// Buttons:
define('MANAGE_MENUS_HEADING', "Manage Menüü Ülesanded");
define('MANAGE_MENUS_CREATE_NEW_MENU_BTN', "Loo uus menüü");
// Console Text:
define('MANAGE_MENUS_ADD_MENU', "Lisa Menu");
define('MANAGE_MENUS_MENU_TYPE', "Menüü Type");
define('MANAGE_MENUS_ASSIGN_MENU_TO_BORDER', "Määra menüü piirialal");
define('MANAGE_MENUS_DELETE_MENU', "Kustuta Menüü");
define('MANAGE_MENUS_SELECT_MENU_TO_DELETE', "Valige menüü, mida soovite kustutada");
define('MANAGE_MENUS_UPDATE_MENU_DESCRIPTION', "Uuenda Menüü Kirjeldus");
define('MANAGE_MENUS_SELECT_MENU_TO_REVISE', "Valige menüü, mida soovite vaadata");
define('MANAGE_MENUS_NEW_DESCRIPTION', "uus kirjeldus");
// Popup Messages:
define('MANAGE_MENUS_REASSIGN_MENU_TO_COMPLETE_MSG', "Sa pead uuesti määrata selle menüü piirialal ülemineku lõpuleviimisel.");
define('MANAGE_MENUS_DELETE_MENU_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
define('MANAGE_MENUS_DELETE_MENU_CONFIRM_2_MSG', "menüü?");
define('MANAGE_MENUS_MENU_ASSIGNED_1_MSG', "");
define('MANAGE_MENUS_MENU_ASSIGNED_2_MSG', "menüü");
define('MANAGE_MENUS_MENU_ASSIGNED_3_MSG', "on määratud");
define('MANAGE_MENUS_MENU_ASSIGNED_4_MSG', "piirialal.");

///////////////////////// Edit CSS Menu Parameters /////////////////////////
// Buttons:
define('EDIT_CSS_MENU_PARAMETERS_HEADING', "CSS Menu Parameetrid Quick-Setup Editor");
// Console Text:
define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU', "Valige menüü Setup");
define('EDIT_CSS_MENU_PARAMETERS_LAYOUT_ORIGIN', "Menüü paigutus ja päritolu (alates vasakul üleval leheküljel)");
define('EDIT_CSS_MENU_PARAMETERS_LOCATION', "Menüü asukoht");
define('EDIT_CSS_MENU_PARAMETERS_FIXED_WIDTH', "(Fikseeritud laiusega)");
define('EDIT_CSS_MENU_PARAMETERS_VARIABLE_WIDTH', "(Muutuva laiusega)");
define('EDIT_CSS_MENU_PARAMETERS_MENU_WIDTH', "Menüü Laius");
define('EDIT_CSS_MENU_PARAMETERS_SPECIAL_NOTE', "Märkus: Valides mistahes eespool asukohad ei pane menüü ühele neist piirkondadest. See lihtsalt tõstab esile seda vormi tüüpiline seaded valitud piirkonnas.");
define('EDIT_CSS_MENU_PARAMETERS_ITEM_SIZE_PADDING', "Menüüvalik Suurus ja polster");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_POSITIONING', "Sub Menüü positsioneerimissüsteemi");
define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_TOP', "Nihe on Top");
define('EDIT_CSS_MENU_PARAMETERS_OFFSET_FROM_LEFT', "Nihe vasakult");
define('EDIT_CSS_MENU_PARAMETERS_COLLAPSE_EXPAND', "Sulge ja laiendamine");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_SIZE_PADDING', "Alammenüü kirjet Suurus ja polster");
define('EDIT_CSS_MENU_PARAMETERS_SELECT_MENU_MSG', "Palun valige menüü seadistus.");

///////////////////////// Edit CSS Menu Styles /////////////////////////
// Buttons:
define('EDIT_CSS_MENU_STYLES_HEADING', "CSS menüü stiilid Quick-Setup Editor");
// Console Text:
define('EDIT_CSS_MENU_STYLES_SELECT_MENU', "Valige menüü, stiili");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_FONT', "Top Level Font");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_FONT', "Sub Level 1 Font");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_FONT', "Sub Level 2 Font");
define('EDIT_CSS_MENU_STYLES_COLORS_BACKGROUND', "Värvid ja taust");
define('EDIT_CSS_MENU_STYLES_NORMAL_MOUSE_OUT', "Tavaline (hiir välja)");
define('EDIT_CSS_MENU_STYLES_HOVER_MOUSE_OVER', "Hover (hiir)");
define('EDIT_CSS_MENU_STYLES_ACTIVE_MOUSE_CLICK', "Aktiivne (hiireklõpsuga)");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_TEXT_COLOR', "Top Level Tekstivärv");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_TEXT_COLOR', "Sub Level 1 Tekstivärv");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_TEXT_COLOR', "Sub Level 2 Tekstivärv");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BACKGROUND_COLOR', "Top Level Tausta värv");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BACKGROUND_COLOR', "Sub Tase Tausta värv");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_BLOCK_BORDER_COLOR', "Top Level Block Piirdevärvi");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_BLOCK_BORDER_COLOR', "Sub Tase Block Piirdevärvi");
define('EDIT_CSS_MENU_STYLES_TOP_LEVEL_ITEM_BORDER_COLOR', "Top Level Piirdevärvi");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_ITEM_BORDER_COLOR', "Sub Level Piirdevärvi");
define('EDIT_CSS_MENU_STYLES_TOP_BORDER_VERTICAL', "T <br> o <br> p");
define('EDIT_CSS_MENU_STYLES_BOTTOM_BORDER_VERTICAL', "B <br> o <br> t <br> t <br> o <br> m");
define('EDIT_CSS_MENU_STYLES_LEFT_BORDER_VERTICAL', "L <br> e <br> f <br> t");
define('EDIT_CSS_MENU_STYLES_RIGHT_BORDER_VERTICAL', "R <br> mina <br> g <br> h <br> t");
define('EDIT_CSS_MENU_STYLES_UNDERLINE_NOTE', "Link-underline on sunnitud välja arvatud juhul, kui rõhutada kontrollitakse");
define('EDIT_CSS_MENU_STYLES_SAME_AS_TOP_LEVEL_NOTE', "(Sama tipptasemel)");
define('EDIT_CSS_MENU_STYLES_SAME_AS_NORMAL_NOTE', "(Sama normaalne)");
define('EDIT_CSS_MENU_STYLES_SELECT_MENU_MSG', "Palun valige menüü stiili.");
// Popup Messages:
define('EDIT_CSS_MENU_STYLES_LETTER_SPACING_MSG', "Oled valinud <b>Tavaline</b> <b>esmane</b> või <b>päritud</b> oma Tähevahe, kuid sul on mitmeid seatud Tähevahe. Pange tähele, et number olete valinud ignoreeritakse. Kui soovite määrata Tähevahe vali <b>px</b> asemel.");
define('EDIT_CSS_MENU_STYLES_SAVE_SUCCESS_MSG', "Teie menüü stiilid on salvestatud.");
define('EDIT_CSS_MENU_STYLES_SAVE_FAIL_ERR', "Tekkis viga salvestamiseks menüü stiilid.");

///////////////////////// Edit JS Menu Parameters /////////////////////////
// Buttons:
define('EDIT_JS_MENU_PARAMETERS_HEADING', "JavaScript Menüü suuruse ja orientatsiooni Editor");
// Console Text:
define('EDIT_JS_MENU_PARAMETERS_SELECT_MENU', "Valige menüü Setup");
define('EDIT_JS_MENU_PARAMETERS_MENU_ITEM_SIZE', "Menüüvalik Suurus");
define('EDIT_JS_MENU_PARAMETERS_MENU_ORIGIN', "Menüü päritolu (alates vasakul üleval leheküljel)");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_ORIGIN', "Sub Menüü päritolu (alates vasakul üleval Main Menu)");
define('EDIT_JS_MENU_PARAMETERS_MENU_ITEM_OFFSET', "Menüüvalik Nihe");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_ITEM_OFFSET_SIZE', "Alammenüü kirjet Offset ja suurus");
define('EDIT_JS_MENU_PARAMETERS_PROPORTIONAL_SIZING', "proportsionaalne Suurus");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_WIDTH', "Alammenüü kirjet Laius");
define('EDIT_JS_MENU_PARAMETERS_SUB_MENU_HEIGHT', "Alammenüü kirjet Kõrgus");
define('EDIT_JS_MENU_PARAMETERS_OFFSET_FROM_LEFT_OF_TOP_MENU', "Nihe vasakult Top Menu");
define('EDIT_JS_MENU_PARAMETERS_HIDE_DELAY_ON_MOUSE_OUT', "Peida viivituse pärast Mouse Out (ms)");
define('EDIT_JS_MENU_PARAMETERS_VERTICAL_HORIZONTAL_MENU_NOTE', "Märkus: vertikaalse menüü komplekt Offset vasakult 0. horisontaalne menüü komplekt nihkes Top 0.");
define('EDIT_JS_MENU_PARAMETERS_SELECT_MENU_MSG', "Palun valige menüü seadistus.");
// Popup Messages:
define('EDIT_JS_MENU_PARAMETERS_SAVE_SUCCESS_MSG', "Teie menüü parameetrid on salvestatud.");
define('EDIT_JS_MENU_PARAMETERS_SAVE_FAIL_ERR', "Tekkis viga salvestamiseks menüü parameetrid.");

///////////////////////// Edit JS Menu Styles /////////////////////////
// Buttons:
define('EDIT_JS_MENU_STYLES_HEADING', "JavaScript Menüü Laadiredaktor");
// Console Text:
define('EDIT_JS_MENU_STYLES_SELECT_MENU', "Valige menüü, stiili");
define('EDIT_JS_MENU_STYLES_TOP_MENU_MENU', "Top-Level Menu");
define('EDIT_JS_MENU_STYLES_SUB_LEVEL_1_MENU', "Alamtase 1 Menüü");
define('EDIT_JS_MENU_STYLES_SUB_LEVEL_2_MENU', "Alamtase 2 Menüü");
define('EDIT_JS_MENU_STYLES_PADDING', "Täidis (üleval paremal all vasakul)");
define('EDIT_JS_MENU_STYLES_SELECT_MENU_MSG', "Palun valige menüü stiili.");

///////////////////////// Edit CSS Select /////////////////////////
// Buttons:
define('EDIT_CSS_SELECT_HEADING', "Edit Styles");
define('EDIT_CSS_SELECT_COPY_STYLES_TO_MOBILE_BTN', "Kopeeri Style Sheet Mobile");
define('COPY_STYLE_TO_MOBILE_NOTE', "See funktsioon on ettenähtud mobiilne stiilid analoogsete töölauastiilid kui olete lõpetanud luua oma stiili lehed töölaual vaadata. Kasutamine Selle funktsiooniga kirjutatakse stiilid olete loonud mobiilse laadilehte te kopeerimist. Ei ole vaja, et kasutada seda funktsiooni, kuid see võib olla mugav lähtepunktiks luua oma mobiiltelefoni stiile. Samuti võite luua oma mobiiltelefoni CSS stiili lehed, mis ei ole analoogne mobiiltelefoni CSS vaikimisi.");
define('COPY_STYLE_TO_MOBILE_CONFIRM_1_MSG', "Oled kindel, et soovite kopeerida");
define('COPY_STYLE_TO_MOBILE_CONFIRM_2_MSG', "? Kõik stiilid");
define('COPY_STYLE_TO_MOBILE_CONFIRM_3_MSG', "kirjutatakse üle. (Seda ei saa olematuks teha.)");
define('COPY_STYLE_TO_MOBILE_COMPLETE_MSG', "on kopeeritud");
define('COPY_STYLE_TO_MOBILE_COMPLETE_ERR', "Tekkis viga kopeerimise");
// Popup Messages:
define('EDIT_CSS_SELECT_MENU_WARNING', "HOIATUS: toimetamine menüü CSS otse võib põhjustada ettearvamatuid tulemusi. Menüü stiil tuleks kasutada menüü stiili toimetajad. Montaaž menüü CSS CSS redaktor tuleks teha ainult ekspert veebiarendajad.");
define('EDIT_CSS_SELECT_MENU_ITEM_WARNING', "NB: Kui styling individuaalne menüü seatud &quot;Display&quot; kuni &quot;Nimekiri Punkt&quot; aktiveerida neid brausereid.");

///////////////////////// Edit CSS /////////////////////////
// Buttons:
define('EDIT_CSS_HEADING', "Edit Styles");
define('EDIT_CSS_ADD_DELETE_CUSTOM_STYLE_BTN', "Lisa / Kustuta Custom Style");
define('EDIT_CSS_LOAD_BROWSER_RESET_CSS_BTN', "Load Browser Reset CSS");
define('EDIT_CSS_SETUP_CENTERED_PAGES_BTN', "Setup keskele Lehekülgede");
define('EDIT_CSS_SETUP_STICKY_FOOTER_BTN', "Setup kleepjates jalus");
// Console Text:
define('EDIT_CSS_CHANGE_STYLE_SHEET', "Muuda Style Sheet");
define('EDIT_CSS_USE_SETTINGS_BELOW', "Kasutage allpool toodud seadistusi");
define('EDIT_CSS_GO_TO', "Minema");
define('EDIT_CSS_SORT_ALPHABETICALLY', "Sorteeri tähestiku");
define('EDIT_CSS_CLICK_NONE_MSG', "Vajuta &quot;ei ole&quot; ainult otseselt rakendada ei teksti kaunistamiseks.");
define('EDIT_CSS_WHITE_SPACE', "tühiruumi");
define('EDIT_CSS_TABLE_LAYOUT', "Tabel Layout");
define('EDIT_CSS_CURSOR', "kursor");
define('EDIT_CSS_OUTLINE_STYLE', "Puu Style");
define('EDIT_CSS_BORDER_COLLAPSE', "piirivalve Collapse");
define('EDIT_CSS_TOP_LEFT', "Üleval vasakul");
define('EDIT_CSS_TOP_RIGHT', "Top Right");
define('EDIT_CSS_BOTTOM_RIGHT', "Paremalt alumine");
define('EDIT_CSS_BOTTOM_LEFT', "All vasakul");
define('EDIT_CSS_Z_INDEX', "Z Index");
define('EDIT_CSS_BACKGROUND_IMAGE', "Taustapilt");
define('EDIT_CSS_CLICK_AUTO_MSG', "Vajuta &quot;Auto&quot; ainult selgesõnaliselt jõustada auto marginaal.");
define('EDIT_CSS_REPEAT_HORIZONTALLY', "Korda horisontaalselt");
define('EDIT_CSS_REPEAT_VERTICALLY', "Korda vertikaalselt");
define('EDIT_CSS_NO_REPEAT', "Ära korda");
define('EDIT_CSS_INLINE_BLOCK', "Inline-Block");
define('EDIT_CSS_LIST_ITEM', "Nimekiri toode");
define('EDIT_CSS_RUN_IN', "Jooks");
define('EDIT_CSS_INLINE_TABLE', "inline tabel");
define('EDIT_CSS_TABLE_ROW_GROUP', "Tabel Row Group");
define('EDIT_CSS_TABLE_FOOTER_GROUP', "Tabel jalus Group");
define('EDIT_CSS_TABLE_ROW', "Tabel Row Group");
define('EDIT_CSS_TABLE_COLUMN_GROUP', "Tabel veerg Group");
define('EDIT_CSS_TABLE_COLUMN', "Tabel veerg Group");
define('EDIT_CSS_TABLE_CELL', "Tabel Cell");
define('EDIT_CSS_TABLE_CAPTION', "Tabel Caption");
define('EDIT_CSS_ALL_SCROLL', "Kõik Leidke");
define('EDIT_CSS_CONTEXT_MENU', "Kontekstimenüüle");
define('EDIT_CSS_COLUMN_RESIZE', "veerg Resize");
define('EDIT_CSS_ROW_RESIZE', "rida Resize");
define('EDIT_CSS_NO_DROP', "No-Drop");
define('EDIT_CSS_NOT_ALLOWED', "Ei ole lubatud");
define('EDIT_CSS_VERTICAL_TEXT', "vertikaaltekst");
define('EDIT_CSS_EAST_RESIZE', "Ida-Resize");
define('EDIT_CSS_EAST_WEST_RESIZE', "Ida-Lääne Resize");
define('EDIT_CSS_NORTH_RESIZE', "Põhja Resize");
define('EDIT_CSS_NORTH_EAST_RESIZE', "Kirde-Resize");
define('EDIT_CSS_NORTH_EAST_SOUTH_WEST_RESIZE', "Põhja-Ida-ja Lõuna-West Resize");
define('EDIT_CSS_NORTH_SOUTH_RESIZE', "Põhja-lõuna Resize");
define('EDIT_CSS_NORTH_WEST_RESIZE', "Loode-Resize");
define('EDIT_CSS_NORTH_WEST_SOUTH_EAST_RESIZE', "Loode-, Kagu-Resize");
define('EDIT_CSS_SOUTH_RESIZE', "Lõuna Resize");
define('EDIT_CSS_SOUTH_EAST_RESIZE', "Kagu-Resize");
define('EDIT_CSS_SOUTH_WEST_RESIZE', "Edela-Resize");
define('EDIT_CSS_WEST_RESIZE', "Lääne Resize");
define('EDIT_CSS_ZOOM_IN', "Suurenda");
define('EDIT_CSS_ZOOM_OUT', "Suumi välja");
define('EDIT_CSS_TOP_CENTER', "Top Center");
define('EDIT_CSS_CENTER_LEFT', "Center Vasak");
define('EDIT_CSS_CENTER_CENTER', "Center Center");
define('EDIT_CSS_CENTER_RIGHT', "Center Right");
define('EDIT_CSS_BOTTOM_CENTER', "alumine Center");
define('EDIT_CSS_XPOS_YPOS', "Xpos Ypos");
define('EDIT_CSS_DECIMAL_LEADING_ZERO', "Kohaga nullita");
define('EDIT_CSS_LOWER_ROMAN', "Alumine Roman");
define('EDIT_CSS_UPPER_ROMAN', "ülemine Roman");
define('EDIT_CSS_LOWER_ALPHA', "Alumine Alpha");
define('EDIT_CSS_UPPER_ALPHA', "ülemine Alpha");
define('EDIT_CSS_LOWER_GREEK', "Alumine Kreeka");
define('EDIT_CSS_LOWER_LATIN', "Alumine Ladina");
define('EDIT_CSS_UPPER_LATIN', "ülemine Ladina");
define('EDIT_CSS_CJK_IDEOGRAPHIC', "CJK--Ideographic");
define('EDIT_CSS_HIRAGANA', "hiragana");
define('EDIT_CSS_KATAKANA', "katakana");
define('EDIT_CSS_HIRAGANA_IROHA', "hiragana Iroha");
define('EDIT_CSS_KATAKANA_IROHA', "katakana Iroha");
// Popup Messages:
define('EDIT_CSS_CLICK_UPDATE_TO_COMMIT_MSG', "Vajuta &quot;Uuenda&quot; toime muutustega.");
define('EDIT_CSS_UPDATE_COMPLETE_MSG', "Uuenda kogu");
define('EDIT_CSS_UPDATE_READY_TO_SEND_MSG', "Uuenda valmis saatma ...");
define('EDIT_CSS_UPDATE_SENT_MSG', "Uuenda saata");
define('EDIT_CSS_UPDATING_MSG', "Uuendamine ...");
define('EDIT_CSS_RESET_BROWSER_CSS_COMPLETE_MSG', "Teie CSS seadistamiseks on taastada brauserid seades kõik marginaalid, pehmendused ja piirid HTML element 0, ja kõik marginaalid keha element 0.");
define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_ALERT_MSG', "Nüüd laadida stiilid seadetega, mis paneb oma kodulehel keskele ilmub fikseeritud laiusega.");
define('EDIT_CSS_LOAD_CENTERED_PAGES_CSS_COMPLETE_MSG', "Sait on tsentreeritud. Soovi korral saab muuta &quot;keha&quot; laius, siis &quot;keha&quot; taustavärvi ja &quot;#wrap&quot; backgound värvi teie vajadustele.");
define('EDIT_CSS_LOAD_STICKY_FOOTERS_ALERT_MSG', "Nüüd laadida stiilid seadetega, mis paneb jalus oma veebilehti &quot;kepp&quot; põhja brauseri aken.");
define('EDIT_CSS_LOAD_STICKY_FOOTERS_COMPLETE_MSG', "Teie jalus nüüd kinni põhjas brauseriaknas. Võite vaadata läbi &quot;jalus&quot; kõrgus ja taustavärvi teie vajadustele. Kindlasti seatud jalus marginaal top sama, kuid negatiivne jalus kõrgus.");
define('EDIT_CSS_BORDER_REQUIREMENTS_MSG', "Tundub, et sa üritad setup piiri, aga sa ei ole veel ühtegi küljed valitud. Sa pead kontrollima vähemalt ühte kasti nimega <b>Top,</b> <b>Bottom,</b> <b>vasakule</b> või <b>paremale.</b>");
define('EDIT_CSS_BORDER_REQUIREMENTS_STYLE_ADENDUM_MSG', "Määrata tuleb <b>piiri stiilis</b> selleks piiriks näidata.");
define('EDIT_CSS_LETTER_SPACING_REQUIREMENTS_MSG', "Oled valinud <b>Tavaline</b> <b>esmane</b> või <b>päritud</b> oma Tähevahe, kuid sul on mitmeid seatud Tähevahe. Pange tähele, et number olete valinud ignoreeritakse. Kui soovite määrata Tähevahe vali <b>px</b> asemel.");
define('EDIT_CSS_LINE_HEIGHT_REQUIREMENTS_MSG', "Oled valinud <b>Tavaline</b> või <b>päritud</b> oma rida kõrgust, kuid teil on positiivne arv seatud line kõrgus. Pange tähele, et number olete valinud ignoreeritakse. Kui soovite määrata rea kõrgusele, valida <b><b>Bultiplyer,%</b></b> või <b>px</b> asemel.");
define('EDIT_CSS_SORTING_CLASS_LIST_MSG', "Sorteerimine klassi nimekirjas ...");
define('EDIT_CSS_SORT_COMPLETE', "Sorteeri täielik");
define('EDIT_CSS_SORTING_MSG', "Sorteerimine ...");
define('EDIT_CSS_COULD_NOT_RENAME_1_ERR', "Ei saa ümber nimetada");
define('EDIT_CSS_COULD_NOT_RENAME_2_ERR', "kuni");
define('EDIT_CSS_CANT_CREATE_ERR', "Ei saa luua");
define('EDIT_CSS_SELECT_PAGE_FOR_PREVIEW', "Vali lehe eelvaate CSS muutusi");

///////////////////////// Edit CLASSES /////////////////////////
// Buttons:
define('CLASSES_HEADING', "Lisa / Kustuta Custom Style");
define('CLASSES_BACK_TO_EDIT_CSS', "Tagasi Muuda Saidi CSS");
// Console Text:
define('CLASSES_ADD_CLASS', "Lisa klass");
define('CLASSES_CREATE_SUB_CLASS', "Loo klass / alamklassi seose");
define('CLASSES_DELETE_CLASS', "Kustuta klass");
define('CLASSES_EDIT_CLASS_DESCRIPTION', "Edit klassi kirjeldus");
define('CLASSES_SET_CLASS_SORT_ORDER', "Määra klassi Järjekord");
define('CLASSES_CREATE_LINK_SET', "Loo Lingikogum");
define('CLASSES_CLASS_DESCRIPTION', "Klass / Kirjeldus");
define('CLASSES_CLASS_ID_NOTE', "Vali &quot;Klass&quot; eest. (Dot) eesliide või valige &quot;ID&quot; jaoks # eesliide.");
define('CLASSES_COPY_CLASS', "Copy / Nimeta klass");
define('CLASSES_FROM_CLASS', "klassi");
define('CLASSES_TO_CLASS', "klassi");
define('CLASSES_TO_STYLE_SHEET', "Et Style Sheet");
define('CLASSES_NO_CUSTOM_CLASSES_DEFINED', "no kohandatud klassid denfined-");
// Popup Messages:
define('CLASSES_DELETE_CLASS_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada klass");
define('CLASSES_DELETE_CLASS_CONFIRM_2_MSG', "?");
define('CLASSES_DESCRIPTION_NOT_FOUND_MSG', "Salvestusi ei leitud. Ei leia kirjeldust.");
define('CLASSES_DESCRIPTION_FOUND_MSG', "Kirjeldus Leitud");
define('CLASSES_COULD_NOT_UPDATE_DESCRIPTION_MSG', "Kirjet ei leita. Ei saa uuendada kirjeldus.");
define('CLASSES_DESCRIPTION_UPDATED_MSG', "Kirjeldus uuendatud");
define('CLASSES_STARTING_POPULATE_MSG', "Alustades asustada ...");
define('CLASSES_COPY_FROM_CLASS_BLANK_ERR', "Palun valige klassi kopeerida.");
define('CLASSES_COPY_TO_CLASS_BLANK_ERR', "Palun sisesta klassi kopeerida.");
define('CLASSES_COPY_CLASS_COMPLETE_MSG', "Klass koopia valmis!");
define('CLASSES_COPY_CLASS_ERR', "Tekkis viga üritab kopeerida klassi.");
define('CLASSES_COPY_CLASS_TO_CLASS_ALREADY_EXISTS_ERR', "VIGA: Klass püüad kopeerida juba olemas.");
define('CLASSES_UPDATE_SORT_ORDER_COMPLETE_MSG', "Omamoodi tellimused on uuendatud.");
define('CLASSES_UPDATE_SORT_ORDER_UPDATE_ERR', "VIGA: tekkis viga ajakohastamiseks sortimisjärjestust.");
define('CLASSES_ADD_CLASS_COMPLETE_MSG', "Teie uus klass on lisatud.");
define('CLASSES_ADD_CLASS_ADD_ERR', "juba olemas andmebaasis.");
define('CLASSES_DEFINE_SUBCLASS_COMPLETE_MSG', "Teie uus alaliik on loodud.");
define('CLASSES_DEFINE_SUBCLASS_DEFINE_ERR', "VIGA: tekkis viga luua endale alamklass.");
define('CLASSES_DELETE_CLASS_COMPLETE_MSG', "Klass kustutatud.");
define('CLASSES_ADD_CLASS_CANNOT_BE_BLANK_MSG', "Klass / ID nimi ei saa olla tühi. Palun täitke klassi või ID nimi.");

///////////////////////// Edit Head Select /////////////////////////
// Buttons:
define('EDIT_HEAD_SELECT_HEADING', "Edit Head kood");

///////////////////////// Manage Head /////////////////////////
// Buttons:
define('MANAGE_HEAD_HEADING', "Manage Head kood");
define('MANAGE_HEAD_ADD_HEAD_BTN', "Lisa veel üks juht sisu");
// Console Text:
define('MANAGE_HEAD_ADD_HEAD_CONTENT', "Lisa Head Sisu");
define('MANAGE_HEAD_ASSIGN_HEAD_CONTENT_TO_PAGE', "Määra Head Sisu Page");
define('MANAGE_HEAD_RENAME_HEAD_CONTENT', "Nimeta Head Sisu");
define('MANAGE_HEAD_DELETE_HEAD_CONTENT', "Kustuta Head Sisu");
define('MANAGE_HEAD_SELECT_HEAD_CONTENT_TO_RENAME', "Vali juht sisu ümber");
define('MANAGE_HEAD_SELECT_HEAD_CONTENT_TO_DELETE', "Vali juht sisu kustutada");
define('MANAGE_HEAD_NEW_NAME', "uus nimi");
// Popup Messages:
define('MANAGE_HEAD_DELETE_HEAD_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
define('MANAGE_HEAD_DELETE_HEAD_CONFIRM_2_MSG', "pea?");
define('MANAGE_HEAD_DELETED_1_MSG', "Pea");
define('MANAGE_HEAD_DELETED_2_MSG', "on välja jäetud.");
define('MANAGE_HEAD_DELETED_ERR', "Viga: Ei saa lisada peaga");
define('MANAGE_HEAD_NO_HEADS_FOUND_ERR', "Viga: pead leidnud.");
define('MANAGE_HEAD_NOT_FOUND_1_ERR', "ei eksisteeri.");
define('MANAGE_HEAD_NOT_FOUND_2_ERR', "tagasi pähe loovutamise lehel.");
define('MANAGE_HEAD_ASSIGNED_1_MSG', "on uuesti määratud");
define('MANAGE_HEAD_ASSIGNED_2_MSG', "lehel.");
define('MANAGE_HEAD_ASSIGNED_1_ERR', "Viga: Ei saa määrata");
define('MANAGE_HEAD_ASSIGNED_2_ERR', "Euroopa");
define('MANAGE_HEAD_ASSIGNED_3_ERR', "lehel.");
define('MANAGE_HEAD_ADDED_1_MSG', "Pea");
define('MANAGE_HEAD_ADDED_2_MSG', "on lisatud.");
define('MANAGE_HEAD_ADDED_ERR', "Viga: Ei saa lisada peaga");
define('MANAGE_HEAD_PAGE_ALREADY_EXISTS_1_ERR', "Pea");
define('MANAGE_HEAD_PAGE_ALREADY_EXISTS_2_ERR', "juba eksisteerib. Palun sisesta teine ​​juht nimi.");
define('MANAGE_HEAD_ALREADY_ASSIGNED_1_ERR', "Ei saa määrata");
define('MANAGE_HEAD_ALREADY_ASSIGNED_3_ERR', "lehte, sest see on juba määratud.");

///////////////////////// Edit Favicon /////////////////////////
// Buttons:
define('EDIT_FAVICON_HEADING', "Edit Favicon");
define('EDIT_FAVICON_UPLOAD_BTN', "Laadi üles");
// Console Text:
define('EDIT_FAVICON_UPLOAD_FAVICON', "Laadi Favicon");
// Popup Messages:
define('EDIT_FAVICON_DELETE_FAVICON_CONFIRM', "Olete kindel, et soovite kustutada ikoon?");
define('EDIT_FAVICON_UPLOAD_SUCCESS_MSG', "Favicon on üles laaditud.");
define('EDIT_FAVICON_ONLY_ICONS_ALLOWED_MSG', "Ainult ikooni faile on lubatud üles laadida, st &quot;myicon.ico&quot;. Palun kliki");
define('EDIT_FAVICON_UPLOAD_FAIL_ERR', "Tekkis viga üleslaadimisel faili.");

///////////////////////// Edit Page Titles /////////////////////////
// Buttons:
define('EDIT_PAGE_TITLES_HEADING', "Muuda pealkirjas");
// Console Text:
define('EDIT_PAGE_TITLES_REVISE_DEFAULT_PAGE_TITLE', "Vaadata Alglehekülje Pealkiri");
define('EDIT_PAGE_TITLES_SELECT_PAGE', "Vali lehel muuta pealkiri");
define('EDIT_PAGE_TITLES_REVISE_SITE_TITLE', "Vaadata Site Title");
define('EDIT_PAGE_TITLES_SITE_TITLE_NOTE', "lisatud lehekülje pealkiri, kui on olemas");
// Popup Messages:
define('EDIT_PAGE_TITLES_PAGE_TILE_SAVED_MSG', "Lehe pealkiri on salvestatud.");

///////////////////////// Edit Meta Tags /////////////////////////
// Buttons:
define('EDIT_META_TAGS_HEADING', "Edit Meta Tags");
// Console Text:
define('EDIT_META_TAGS_SELECT_PAGE', "Vali lehel");
define('EDIT_META_TAGS_KEYWORDS_NOTE', "Märkus: Kasutage koma &quot;,&quot; eraldi võtmesõnad ja võti laused.");
// Popup Messages:
define('EDIT_META_TAGS_META_TAGS_SAVED_MSG', "Meta tags on salvestatud.");

///////////////////////// Delete Page or Blog /////////////////////////
// Buttons:
define('DELETE_PAGE_OR_BLOG_HEADING', "Kustuta lehekülg või Blogi");
// Console Text:
define('DELETE_PAGE_OR_BLOG_SELECT_PAGE', "Valige leht, mida soovite kustutada");
define('DELETE_PAGE_OR_BLOG_SELECT_BLOG', "Vali blogi postitus, mida soovite kustutada");
// Popup Messages:
define('DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_1_MSG', "Kas teie kindel, et soovid kustutada");
define('DELETE_PAGE_OR_BLOG_DELETE_BLOG_CONFIRM_2_MSG', "?");
define('DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_1_MSG', "Kas teie kindel, et soovid kustutada");
define('DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG', "leheküljel?");
define('DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG', "Kas teie kindel, et tahad meenutada");
define('DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG', "sisse panema?");

///////////////////////// Copy/Raname Select Page /////////////////////////
// Buttons:
define('COPY_RENAME_PAGE_HEADING', "Kopeeri või Nimeta Lehekülgede");
define('COPY_RENAME_PAGE_COPY_RENAME_BTN', "Copy / Rename");
// Console Text:
define('COPY_RENAME_PAGE_DISCARD_TEMPLATE_NOTE', "Loobu vana külje ja luua uusi");
define('COPY_RENAME_PAGE_RENAME_PAGE_LINK_NOTE', "Märkus: ümbernimetamine lehel ei muutu mingeid seoseid, mida olete loonud. Menüüelemente uuendatakse automaatselt, kuid siis on vaja midagi muuta seoseid tahes lehtedel viitamiseks uue lehe nimi.");

///////////////////////// Copy/Raname Page /////////////////////////
// Buttons:
define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_BTN', "ülekirjutamine kohtades");
define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_RETAIN_TEMPLATE_BTN', "Kas kirjutada kohtades sisu, kuid säilitavad kohtades malli");
define('COPY_RENAME_PAGE_OVERWRITE_DESTINATION_CREATE_NEW_TEMPLATE_BTN', "Ülekirjutamine sihtkohta lähtekoodiga sisu luua uue malli kohta valitud kohas valikud");
define('COPY_RENAME_PAGE_CANCEL_COPY_BTN', "Tühista koopia ja tagasi copy / ümber konsooli");
// Console Text:
define('COPY_RENAME_PAGE_PAGE_ALREADY_EXISTS', "juba eksisteerib. Mida sa teha tahad?");
// Popup Messages:
define('COPY_RENAME_PAGE_FORGOT_TO_SELECT_PAGE_TO_RENAME_1_MSG', "Oops! Sa unustasid, et valida leht ümber.");
define('COPY_RENAME_PAGE_FORGOT_TO_SELECT_PAGE_TO_RENAME_2_MSG', "ning valida lehekülje ümber nimetada.");
define('COPY_RENAME_PAGE_FORGOT_TO_ENTER_NEW_PAGE_NAME_1_MSG', "Oops! Sa unustasid sisestada uue lehe nimi.");
define('COPY_RENAME_PAGE_FORGOT_TO_ENTER_NEW_PAGE_NAME_2_MSG', "ja sisestada uue lehe nimi.");
define('COPY_RENAME_PAGE_COPY_ONTO_SELF_1_MSG', "Sa ei saa kopeerida lehekülje peale ise. (Kui olete valinud, et viska vana malli ja luua uus.)");
define('COPY_RENAME_PAGE_COPY_ONTO_SELF_2_MSG', "ja sisestada uue lehe nimi.");
define('COPY_RENAME_PAGE_ERROR_OPENING_NEW_PAGE_ERR', "Viga avades uue lehekülje faili. Palun pöörduge oma süsteemiadministraatori poole.");
define('COPY_RENAME_PAGE_ERROR_UPDATING_PAGE_NAME_REFERENCES_ERR', "Viga ajakohastamiseks lehe nimi viited uus leht faili. Palun pöörduge oma süsteemiadministraatori poole.");
define('COPY_RENAME_PAGE_ERROR_CLOSING_NEW_PAGE_AFETR_REFERENCE_UPDATE_ERR', "Viga sulgemise lehe nimi viited uus leht faili. Palun pöörduge oma süsteemiadministraatori poole.");
define('COPY_RENAME_PAGE_TO_RETURN_TO_COPY_RENAME_CONSOLE', "naasta copy / nimettävää konsooli.");
define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_1_ERR', "lehte");
define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_2_ERR', "juba eksisteerib. Sa ei saa ümber");
define('COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_3_ERR', "ja sisestage eri kohtades nimi.");
define('COPY_RENAME_PAGE_UNKNOWN_ERROR_ERR', "Mõned, kuidas me ei saa kindlaks teha, kas soovite kopeerida või ümber nimetada. Palun mine tagasi ja vali nimekirjast soovitud.");
define('COPY_RENAME_PAGE_RENAME_OLD_PAGE_NOT_FOUND_ERR', "ei leitud. Palun pöörduge oma süsteemiadministraatori poole.");
define('COPY_RENAME_PAGE_ERROR_RENAMING_PAGE_ERR', "Viga ümbernimetamine faili. Palun pöörduge oma süsteemiadministraatori poole.");
define('COPY_RENAME_PAGE_ERROR_OPENING_ORIGINAL_PAGE_ERR', "Viga avamisel algse lehe fail. Palun pöörduge oma süsteemiadministraatori poole.");
define('COPY_RENAME_PAGE_ERROR_WRITING_TO_NEW_PAGE_ERR', "Viga sisu uue lehe fail. Palun pöörduge oma süsteemiadministraatori poole.");
define('COPY_RENAME_PAGE_ERROR_CLOSING_NEW_PAGE_ERR', "Viga sulgemist uue lehe fail. Palun pöörduge oma süsteemiadministraatori poole.");
define('COPY_RENAME_PAGE_CANT_READ_ERR', "Ei saa lugeda");

///////////////////////// Restore Page /////////////////////////
// Buttons:
define('RESTORE_PAGE_HEADING', "Restore Page");
define('RESTORE_PAGE_SHOW_CONTENT_BTN', "Näita Sisu");
define('RESTORE_PAGE_SHOW_CODE_BTN', "Näita kood");
// Console Text:
define('RESTORE_PAGE_SELECT_PAGE', "Valige leht, mida soovite taastada");
define('RESTORE_PAGE_DELETE_FROM_HISTORY', "Kustuta ajalugu");
// Popup Messages:
define('RESTORE_PAGE_DELETE_BACKUP_CONFIRM_1_MSG', "Oled sa kindel, <b>et</b> soovid <b>kustutada</b>");
define('RESTORE_PAGE_DELETE_BACKUP_CONFIRM_2_MSG', "lk backup ajalugu?");
define('RESTORE_PAGE_RESTORE_PAGE_CONFIRM_1_MSG', "Oled sa kindel, et soovid <b>taastada</b>");
define('RESTORE_PAGE_RESTORE_PAGE_CONFIRM_2_MSG', "leheküljel?");

///////////////////////// Add Plugin to Page /////////////////////////
// Buttons:
define('ADD_PLUGIN_TO_PAGE_HEADING', "Install Plugin Into Page");
define('ADD_PLUGIN_TO_PAGE_SELECT_PAGE_HEADING', "Vali Page");
define('ADD_PLUGIN_TO_PAGE_SELECT_PLUGIN_HEADING', "Vali plugina");
// Console Text:
define('ADD_PLUGIN_TO_PAGE_PAGE_SELECTED', "lk valitud");
define('ADD_PLUGIN_TO_PAGE_PLUGIN_SELECTED', "plugin valitud");
// Popup Messages:
define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_1_MSG', "");
define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_2_MSG', "plugin on sisestatud");
define('ADD_PLUGIN_TO_PAGE_PLUGIN_HAS_BEEN_ADDED_TO_PAGE_3_MSG', "lehel.");
define('ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_1_MSG', "Oops! Unustasid lehekülje valida ja / või plugin.");
define('ADD_PLUGIN_TO_PAGE_PAGE_OR_PLUGIN_NOT_SELECTED_2_MSG', "ning valida lehekülje ja plugin.");
define('ADD_PLUGIN_TO_PAGE_ERROR_OPENING_PAGE_FILE_ERR', "Viga avalehekülg faili. Palun pöörduge oma süsteemiadministraatori poole.");
define('ADD_PLUGIN_TO_PAGE_ERROR_UPDATING_PAGE_FILE_ERR', "Viga ajakohastamiseks lehe fail. Palun pöörduge oma süsteemiadministraatori poole.");
define('ADD_PLUGIN_TO_PAGE_ERROR_CLOSING_PAGE_FILE_ERR', "Viga sulgemise lehe fail. Palun pöörduge oma süsteemiadministraatori poole.");
define('ADD_PLUGIN_TO_PAGE_RETURN_TO_INSERT_PLUGIN_INTO_PAGE_CONSOLE_MSG', "naasta sisestada-plugin-sisse-leheküljeline konsooli.");
define('ADD_PLUGIN_TO_PAGE_COULD_NOT_RENAME_MSG', "Ei saa ümber nimetada");

///////////////////////// Mange Page Access /////////////////////////
// Buttons:
define('MANAGE_PAGE_ACCESS_HEADING', "Manage piiratud küljel ja veebilehe kasutajate");
define('MANAGE_PAGE_ACCESS_ADD_LOGIN_FIELDS_BTN', "Lisa kasutaja sisselogimine <br /> Valdkonnad tabeli");
define('MANAGE_PAGE_ACCESS_ASSIGN_WELCOME_MESSAGE_PAGE_BTN', "Määra Tere Sõnum <br /> Page Kasutaja tabel");
// Console Text:
define('MANAGE_PAGE_ACCESS_RESTRICT_PAGE_ACCESS', "Keelatud Page Access");
define('MANAGE_PAGE_ACCESS_APPROVE_ACCESSTO_USERS', "Kiita Juurdepääs Kasutajad");
define('MANAGE_PAGE_ACCESS_USER_TABLE_SETUP', "Kasutaja Tabel Setup");
define('MANAGE_PAGE_ACCESS_SHOW_LOGIN_LINKS_ALWAYS', "Näita sisse <br /> Lingid alati");
define('MANAGE_PAGE_ACCESS_REQUIRE_LOGIN', "Nõuda sisse");
define('MANAGE_PAGE_ACCESS_LOGIN_PAGE', "Sisäänkirjautumissivu");
define('MANAGE_PAGE_ACCESS_MESSAGE_PAGE', "sõnum Page");
define('MANAGE_PAGE_ACCESS_FIRST_LAST', "(esimene Viimane)");
define('MANAGE_PAGE_ACCESS_OPTIONAL', "(Ei ole kohustuslik)");
define('MANAGE_PAGE_ACCESS_ADDITIONAL_FORMS_NOTE', "Kasutajad lisatakse tavaliselt läbi vormi (d) loodud veebilehel. Vormid alla kuuluvad võimaldada lisaks kasutajaid läbi Breeze Website Builder backend saidi administraatorid ja võimsuse kasutajatele.");
// Popup Messages:
define('MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_1_MSG', "Oled sa kindel, et soovid eemaldada selle kasutaja");
define('MANAGE_PAGE_ACCESS_DELETE_USER_CONFIRM_2_MSG', "?");
define('MANAGE_PAGE_ACCESS_USER_DELETED_1_MSG', "kasutaja");
define('MANAGE_PAGE_ACCESS_USER_DELETED_2_MSG', "välja jäetud");
define('MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada juurdepääs tasemel");
define('MANAGE_PAGE_ACCESS_DELETE_ACCESS_LEVEL_CONFIRM_2_MSG', "?");
define('MANAGE_PAGE_ACCESS_LOCATING_PAGE_RESTRICTIONS_MSG', "Asukoht lehel piirangud ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_PAGE_RESTRICTIONS_MSG', "Kirjet ei leita. Ei saa uuendada lehel piiranguid.");
define('MANAGE_PAGE_ACCESS_PAGE_RESTRICTIONS_UPDATED_MSG', "Page piirangud uuendatud");
define('MANAGE_PAGE_ACCESS_UPDATING_PAGE_RESTRICTIONS_MSG', "Uuendamine lehel piirangud ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_UPDATE_USER_STATUS_MSG', "Kirjet ei leita. Ei saa uuendada kasutaja staatuse.");
define('MANAGE_PAGE_ACCESS_USER_STATUS_UPDATED_MSG', "Kasutaja staatust uuendatud");
define('MANAGE_PAGE_ACCESS_UPDATING_USER_STATUS_MSG', "Uuendamine kasutaja staatus ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_MODIFY_TABLE_MSG', "Ei saa muuta tabelis");
define('MANAGE_PAGE_ACCESS_FIELDS_ADDED_TO_TABLE_MSG', "Valdkonnad lisatud tabel");
define('MANAGE_PAGE_ACCESS_ADDING_FIELDS_TO_TABLE_MSG', "Lisades väljad tabelisse ...");
define('MANAGE_PAGE_ACCESS_WELCOME_MESSAGE_PAGE_ADDED_TO_TABLE_MSG', "Tere sõnum lehele lisatakse tabelis");
define('MANAGE_PAGE_ACCESS_ADDING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG', "Lisades tervitus leht tabel ...");
define('MANAGE_PAGE_ACCESS_COULD_NOT_ADD_DELETE_ACCESS_LEVEL_MSG', "Ei saa lisada ega kustutada tasandil.");
define('MANAGE_PAGE_ACCESS_ACESS_LEVEL_RECORDS_MODIFIED_MSG', "Juurdepääs tasandil kirjet muudetud");
define('MANAGE_PAGE_ACCESS_CHANGING_ACCESS_LEVELS_MSG', "Muutuvad juurdepääsu taset ...");
define('MANAGE_PAGE_ACCESS_LOCATING_ACCESS_LEVELS_MSG', "Asukoht juurdepääsu taset ...");
define('MANAGE_PAGE_ACCESS_LOCATING_USERS_MSG', "Asukoht kasutajad ...");
define('MANAGE_PAGE_ACCESS_REQUIRED_FIELDS_MSG', "Veenduge kujul kasutate kasutajatele on väljad nimed &quot;e&quot;, &quot;kasutajatunnusele&quot; ja &quot;Password&quot;. Kui tabelis valitud loodi kasutades konto loomise vorm plugin, siis nendes valdkondades on juba selles tabelis.");
define('MANAGE_PAGE_ACCESS_RETRIEVING_PAGE_RESTRICTIONS_MSG', "Otsib lehel piirangud ...");
define('MANAGE_PAGE_ACCESS_RETRIEVING_ACCESS_LEVELS_MSG', "Otsib juurdepääsu taset ...");
define('MANAGE_PAGE_ACCESS_RETRIEVING_USERS_MSG', "Otsib kasutajad ...");
define('MANAGE_PAGE_ACCESS_ADDING_LOGIN_FIELDS_TO_TABLE_MSG', "Lisades login väljad tabelisse ...");
define('MANAGE_PAGE_ACCESS_ASSIGNING_WELCOME_MESSAGE_PAGE_TO_TABLE_MSG', "Omistamine tervitus leht tabel ...");
define('MANAGE_PAGE_ACCESS_ADDING_ACCESS_LEVEL_MSG', "Lisades juurdepääsu tase ...");
define('MANAGE_PAGE_ACCESS_REMOVING_ACCESS_LEVEL_MSG', "Juurdepääsu eemaldamine tasemele ...");
define('MANAGE_PAGE_ACCESS_NEW_USER_NOT_ADDED_ERR', "Tekkis viga. Uus kasutaja ei lisatud.");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_1_MSG', "Uus kasutaja");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_2_MSG', "on loodud parool");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_3_MSG', "ja juurdepääsu tasemel");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_4_MSG', "eest");
define('MANAGE_PAGE_ACCESS_NEW_USER_CREATED_5_MSG', "e-posti");
define('MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_1_MSG', "Parooli kasutaja");
define('MANAGE_PAGE_ACCESS_PASSWORD_CHANGED_2_MSG', "on muudatus");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_1_MSG', "kasutaja");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_2_MSG', "on modifitseeritud juurdepääsu tase");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_3_MSG', ", Mille nimi on");
define('MANAGE_PAGE_ACCESS_USER_CHANGED_4_MSG', "ja talle on");
define('MANAGE_PAGE_ACCESS_NO_DATA_FOUND_FOR_USER_ERR', "Viga: leitud andmeid, et kasutaja");
define('MANAGE_PAGE_ACCESS_NO_TABLE_SELECTED_ERR', "Sul peab olema kasutajate tabelis valida, kui soovite nõuavad sisenemiseks lehel. Palun valige kasutaja laud ja proovi uuesti.");
define('MANAGE_PAGE_ACCESS_NO_LOGIN_PAGE_SELECTED_ERR', "Sul peab olema sisselogimise lehele valida, kui soovite nõuavad sisenemiseks lehel. Palun valige sisselogimise lehele ja proovi uuesti. Kui ei ole login lehekülge nimekirjas, siis tuleb kõigepealt luua sisselogimise lehele wich login plugin. Nimi sisselogimise lehele peab sisaldama &quot;login&quot;.");


///////////////////////// Manage Page Attributes /////////////////////////
// Buttons:
define('MANAGE_PAGE_ATTRIBUTES_HEADING', "Manage lehekülje atribuudid");
define('MANAGE_PAGE_ATTRIBUTES_TEMPLATE_HEADING', "Vormingu malli");
// Console Text:
define('MANAGE_PAGE_ATTRIBUTES_PAGE_ATTRIBUTES', "Page atribuudid");
define('MANAGE_PAGE_ATTRIBUTES_USE_PAGE_TABLE_STRUCTURES', "Kasuta Page Tabel Structures");
define('MANAGE_PAGE_ATTRIBUTES_USE_PAGE_TABLE_STRUCTURES_FOR_MOBILE', "Kasuta Page Tabel Structures Mobile");
define('MANAGE_PAGE_ATTRIBUTES_CALL_BODY_ONLOAD_FUNCTION', "Helista Body OnLoad Function");
define('MANAGE_PAGE_ATTRIBUTES_DISABLE_SITE_STYLES_WHEN_EDITING', "Keela Saidi Styles kui toimetamine");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_HEAD', "Sisestage Vaikimisi Head Custom Head");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_HEADER', "Sisestage Vaikimisi Päise Custom Header");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_TOP', "Sisestage Vaikimisi Top Custom Top");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_LEFT', "Sisestage Vaikimisi Vasak Custom Vasak");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_RIGHT', "Sisestage Vaikimisi Right Custom Right");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_BOTTOM', "Sisestage Vaikimisi Bottom Custom Bottom");
define('MANAGE_PAGE_ATTRIBUTES_INSERT_DEFAULT_FOOTER', "Sisestage oletusalatunnistetta Custom Footer");
// Popup Messages:
define('MANAGE_PAGE_ATTRIBUTES_ERROR_RETRIEVING_PAGE_ATTRIBUTES_ERR', "Tekkis viga allalaadimise lehele atribuute.");
define('MANAGE_PAGE_ATTRIBUTES_PAGE_ATTRIBUTES_SAVED_MSG', "Lehekülje atribuudid on salvestatud.");
define('MANAGE_PAGE_ATTRIBUTES_ERROR_SAVING_PAGE_ATTRIBUTES_ERR', "Tekkis viga säästa lehekülje atribuudid.");
define('MANAGE_PAGE_ATTRIBUTES_ERROR_ONLOAD_ERR', "Kui &quot;Call Body OnLoad Function&quot; on märgitud, funktsioon ei saa olla tühi.");

///////////////////////// Upload Template /////////////////////////
// Buttons:
define('UPLOAD_TEMPLATE_HEADING', "Laadi mall");
// Console Text:
define('UPLOAD_TEMPLATE_CONFIRM_MSG', "Kas teie kindel, et tahad laadida uue malli? Jätkates asendatakse praegune sait ja muutused on pöördumatud. Teile antakse valida, kas soovite, et hoida oma lehe sisu, vaid teema ja piirialal sisu välja vahetada.");
define('RERUN_WIZARD_RUN_WIZARD_CONFIRM_MSG', "Kas teie kindel, et tahad uuesti käivitada nõustaja? Jätkates asendatakse praegune sait ja muutused on pöördumatud. Teile antakse valida, kas soovite, et hoida oma lehe sisu, vaid teema ja piirialal sisu välja vahetada.");
define('UPLOAD_TEMPLATE_BUILDING_SITE_MSG', "Ehitusel malli ....");
define('UPLOAD_TEMPLATE_WHEN_COMPLETE_SCROLL_TO_BOTTOM_MSG', "Kui valmis, liikuge alt jätkata.");
define('UPLOAD_TEMPLATE_ALLOWED_FILE_TYPE_MSG', "Ainult gzip faili on lubatud üles laadida, st &quot;template_105.tgz&quot; või &quot;template_26.tar.gz&quot;. Palun kliki");
define('UPLOAD_TEMPLATE_COPYING_USER_FILES_MSG', "Kopeerimine kasutaja failid ...");
define('UPLOAD_TEMPLATE_COPYING_PAGES_MSG', "Kopeerimine lehekülge ...");
define('UPLOAD_TEMPLATE_COPYING_IMAGES_MSG', "Piltide kopeerimine ...");
define('UPLOAD_TEMPLATE_COPYING_CSS_MSG', "Kopeerimine css ...");
define('UPLOAD_TEMPLATE_COPYING_MEDIA_MSG', "Kopeerimine meedia ...");
define('UPLOAD_TEMPLATE_COPYING_FLASH_MSG', "Kopeerimine flash ...");
define('UPLOAD_TEMPLATE_COPYING_SCRIPTS_MSG', "Kopeerimine skriptid ...");
define('UPLOAD_TEMPLATE_COPYING_XML_MSG', "Kopeerimine XML ...");
define('UPLOAD_TEMPLATE_UNABLE_TO_OPEN_DOC_ROOT_ERR', "Dokumenti ei saa avada root.");
define('UPLOAD_TEMPLATE_COULD_NOT_RENAME_ERR', "Ei saa ümber nimetada");
define('UPLOAD_TEMPLATE_CANT_CREATE_ERR', "Ei saa luua");
define('UPLOAD_TEMPLATE_ERROR_UPLOADING_FILE_ERR', "Tekkis viga üleslaadimisel faili.");
define('UPLOAD_TEMPLATE_TO_CONTINUE_MSG', "jätkama.");
define('UPLOAD_TEMPLATE_SQL_FILE_MSG', "SQL faili ...");
define('UPLOAD_TEMPLATE_SQL_FILE_NAME_NOT_DEFINED_ERR', "Fatal error: SQL faili nimi ei ole määratletud.");
define('UPLOAD_TEMPLATE_SQL_MSG', "SQL ...");
define('UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG', "rida (de) kahjustatud.");
define('UPLOAD_TEMPLATE_SELECT_TEMPLATE_FROM_YOUR_COMPUTER', "Vali mall, mida soovite installida arvutisse:");
define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES', "Kustuta kõik leheküljed");
// Popup Messages:
define('UPLOAD_TEMPLATE_DELETE_ALL_PAGES_CONFIRM_MSG', "Olete kindel, et soovite kustutada kõik teie lehe sisu?");
define('UPLOAD_TEMPLATE_UPLOADING_TEMPLATE_PLEASE_WAIT_MSG', "Üleslaadimine malli, palun oota ...");
define('UPLOAD_TEMPLATE_UPLOADING', "Üleslaadimine malli, palun oota ...");

///////////////////////// Admin Function Select /////////////////////////
// Buttons:
define('ADMIN_FUNCTION_SELECT_HEADING', "Kasutajate haldamine ja Site valikud");
define('ADMIN_FUNCTION_SELECT_MANAGE_USERS_BTN', "Kasutajate haldamine");
define('ADMIN_FUNCTION_SELECT_CHANGE_SITE_OPTIONS_BTN', "Muuda Saidi valikud");
define('ADMIN_FUNCTION_SELECT_RESTRICT_PAGE_EDITING_ACCESS_BTN', "Keelatud Page toimetamine Access");
define('ADMIN_FUNCTION_SELECT_GENERATE_SITE_MAP_BTN', "Loo Sisukord");
define('ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_BTN', "Prune Page Edit Backup tabel");
define('ADMIN_FUNCTION_SELECT_PRUNE_BACKUP_FILES_BTN', "Prune CSS, sisukord, <br /> faili muuta backup ja <br /> JavaScript menüü backup faile");
define('ADMIN_FUNCTION_SELECT_CLEAR_CUSTOM_CLASSES_BTN', "Kustuta kõik Custom CSS klass");
define('ADMIN_FUNCTION_SELECT_INSTALL_PLUGIN_BTN', "Install Plugin");
define('ADMIN_FUNCTION_SELECT_RECALL_PLUGIN_BTN', "Meenuta Plugin");
define('ADMIN_FUNCTION_SELECT_INSTALL_UPDATE_BTN', "Installige");
define('ADMIN_FUNCTION_SELECT_RUN_SQL_BTN', "Vii SQL");
define('ADMIN_FUNCTION_SELECT_SHOW_SERVER_INFO_BTN', "Näita Server Information");
define('ADMIN_FUNCTION_SELECT_DEACTIVATE_WEBSITE_BTN', "Deaktiveerida Koduleht");
define('ADMIN_FUNCTION_SELECT_ACTIVATE_WEBSITE_BTN', "Aktiveeri Koduleht");
// Console Text:
define('ADMIN_FUNCTION_SELECT_PRUNE_PAGE_EDIT_BACKUP_TABLE_TO', "Prune lehel muuta backup tabelis");
define('ADMIN_FUNCTION_SELECT_SELECT_PLUGIN_TO_RECALL', "Vali plugin soovite meenutada");
// Popup Messages:
define('ADMIN_FUNCTION_SELECT_DEACTIVATE_SITE_CONFIRM_MSG', "Kas soovite võtta saidil off line?");
define('ADMIN_FUNCTION_SELECT_ACTIVATE_SITE_CONFIRM_MSG', "Kas soovite võtta saidil elada?");
define('ADMIN_FUNCTION_SELECT_BACKUP_FILES_HAVE_BEEN_PRUNED_MSG', "CSS, sisukord ja JavaScript menüü backup failid on kärbitakse.");

///////////////////////// Manage Users /////////////////////////
// Buttons:
define('MANAGE_USERS_HEADING', "Kasutajate haldamine");
// Console Text:
define('MANAGE_USERS_SSL_NOT_PRESENT_WARNING', "<b>HOIATUS:</b> Sa vaatad seda konsooli krüpteerimata ühenduse. Kui lisate kasutajate või muutmata paroolid on soovitatav, et te kasutate krüpteeritud ühendus. Et vahetada krüptitud ühendust käsku");
define('MANAGE_USERS_INVALID_CERTIFICATE_NOTE', "Märkus: SSL sertifikaat ei kehti. Kui see on nii, siis seda sertifikaati vastu niikuinii ja jätkab krüpteeritud ühendus. Ka mõned serverid ei ole SSL sertifikaate paigaldatud, nii et see ei pruugi olla võimalik näha seda konsooli krüpteeritud. Kui klõpsates link ei tööta lihtsalt tagasi-nuppu.");
// Popup Messages:
define('MANAGE_USERS_DELETE_USER_CONFIRM_1_MSG', "Kas teie kindel, et soovid eemaldada selle kasutaja");
define('MANAGE_USERS_DELETE_USER_CONFIRM_2_MSG', "?");
define('MANAGE_USERS_USER_DELETED_1_MSG', "kasutaja");
define('MANAGE_USERS_USER_DELETED_2_MSG', "välja jäetud");
define('MANAGE_USERS_NO_USERS_FOUND_ERR', "Viga: Kasutajaid ei leitud");
define('MANAGE_USERS_NO_DATA_FOUND_FOR_USER_ERR', "Viga: leitud andmeid, et kasutaja");
define('MANAGE_USERS_USER_NOT_ADDED_ERR', "Tekkis viga. Uus kasutaja ei lisatud.");
define('MANAGE_USERS_NEW_USER_ADDED_1_MSG', "Uus kasutaja");
define('MANAGE_USERS_NEW_USER_ADDED_2_MSG', "on loodud parool");
define('MANAGE_USERS_NEW_USER_ADDED_3_MSG', "ja juurdepääsu tasemel");
define('MANAGE_USERS_NEW_USER_ADDED_4_MSG', "eest");
define('MANAGE_USERS_NEW_USER_ADDED_5_MSG', "e-posti");
define('MANAGE_USERS_PASSWORD_CHANGED_1_MSG', "Parooli kasutaja");
define('MANAGE_USERS_PASSWORD_CHANGED_2_MSG', "on muudatus");
define('MANAGE_USERS_USER_MODIFIED_1_MSG', "kasutaja");
define('MANAGE_USERS_USER_MODIFIED_2_MSG', "on modifitseeritud juurdepääsu tase");
define('MANAGE_USERS_USER_MODIFIED_3_MSG', ", Mille nimi on");
define('MANAGE_USERS_USER_MODIFIED_4_MSG', "ja talle on");
define('MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_1_ERR', "Sa pead valima tabeli esimene lisad kasutaja.");
define('MANAGE_USERS_NO_TABLE_TO_ADD_USER_TO_2_ERR', "valida tabelist ja proovi uuesti.");
define('MANAGE_USERS_USER_ALREADY_EXISTS_ERR', "sisestada erinevat kasutajanime.");
define('MANAGE_USERS_NO_TABLE_TO_CHANGE_USER_PASSWORD_ERR', "Sa pead valima tabeli esimene parooli muutmiseks kasutaja.");
define('MANAGE_USERS_NO_TABLE_TO_DELETE_USER_FROM_ERR', "Sa pead valima tabeli esimene kustutada kasutaja.");

///////////////////////// Manage SIte Options /////////////////////////
// Buttons:
define('MANAGE_SITE_OPTIONS_HEADING', "Muuda Saidi valikud");
// Console Text:
// Popup Messages:
define('MANAGE_SITE_OPTIONS_OPTIONS_SAVED_MSG', "Võimalusi on salvestatud.");
define('MANAGE_SITE_OPTIONS_ERROR_SAVING_OPTIONS_ERR', "Tekkis viga säästa võimalusi.");

///////////////////////// Restrict Page Editing Access /////////////////////////
// Buttons:
define('RESTRICT_PAGE_EDITING_HEADING', "Piirata juurdepääsu toimetamine Pages Piiratud kasutajad");
// Console Text:
// Popup Messages:
define('RESTRICT_PAGE_EDITING_RESTRICTIONS_SAVED_MSG', "Page piirangud on salvestatud.");

///////////////////////// Generate Site Map /////////////////////////
// Buttons:
define('GENERATE_SITE_MAP_HEADING', "Loo Sisukord");
// Console Text:
define('GENERATE_SITE_MAP_GENERATING', "Genereerimine saidi kaart ...");
define('GENERATE_SITE_MAP_COULD_NOT_RENAME_1_ERR', "Ei saa ümber nimetada");
define('GENERATE_SITE_MAP_COULD_NOT_RENAME_2_ERR', "kuni");
define('GENERATE_SITE_MAP_ERROR_CREATING_SITEMAP_ERR', "Viga creatng saidi kaart.");
define('GENERATE_SITE_MAP_SITEMAP_REBUILD_COMPLETE', "Sisukaart ehitada valmis!");
define('GENERATE_SITE_MAP_SITEMAP_CREATION_COMPLETE', "Kaart loomise täielik!");
define('GENERATE_SITE_MAP_ROBOT_FILE_CREATED', "Robot loodud fail!");
define('GENERATE_SITE_MAP_CANT_CREATE_ERR', "Ei saa luua");

///////////////////////// Install Plugin /////////////////////////
// Buttons:
define('INSTALL_PLUGIN_HEADING', "Install Plugin");
// Console Text:
define('INSTALL_PLUGIN_PLEASE_ENTER_PASSWORD_FOR_ADMIN', "Palun sisesta parool kasutajakonto");
define('INSTALL_PLUGIN_SELECT_PLUGIN_FROM_YOUR_COMPUTER', "Vali plugin, mida soovite installida oma arvutisse");
define('INSTALL_PLUGIN_INSTALLING_PLUGIN', "Paigaldamine plugin ....");
define('INSTALL_PLUGIN_WRONG_FILE_TYPE_MSG', "Ainult kokkupakitud failid või gzip faili on lubatud üles laadida, st &quot;plugin.zip&quot; või &quot;plugin.tgz&quot; või &quot;plugin.tar.gz&quot;. Palun kliki");
define('INSTALL_PLUGIN_EXTRACTING_FILES', "Taastan failid ...");
define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1_ERR', "Tekkis viga kaevandavad faile zip faili.");
define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1A_ERR', "Tekkis viga kaevandavad faile tar.gz faili.");
define('INSTALL_PLUGIN_ERROR_EXTRACTING_FILES_1B_ERR', "Tekkis viga kaevandavad faile tar faili.");
define('INSTALL_PLUGIN_COPYING_FILES', "Failide kopeerimine ...");
define('INSTALL_PLUGIN_PLUGIN_INSTALLATION_COMPLETE', "Plugin paigaldamine on comlplete.");
define('INSTALL_PLUGIN_ADD_NEW_BUTTON_TO_MENU_MSG', "lisada uue plugin nuppu menüü.");
define('INSTALL_PLUGIN_ERROR_UPLOADING_FILE_ERR', "Tekkis viga üleslaadimisel faili.");
// Popup Messages:

///////////////////////// Install Update /////////////////////////
// Buttons:
define('INSTALL_UPDATE_HEADING', "Installige");
// Console Text:
define('INSTALL_UPDATE_SELECT_UPDATE_FROM_YOUR_COMPUTER', "Valige uuendus, mida soovite installida oma arvutisse");
define('INSTALL_UPDATE_INSTALLING_UPDATE', "Paigaldamine uuendus ....");
define('INSTALL_UPDATE_WRONG_FILE_TYPE_MSG', "Ainult gzip faili või kokkupakitud failid on lubatud üles laadida, st &quot;breeze_update_x.x.xx.tgz&quot; või &quot;breeze_update_x.x.xx.tar.gz&quot; või &quot;breeze_update_x.x.xx.zip&quot;. Palun kliki");
define('INSTALL_UPDATE_UPDATE_INSTALLATION_COMPLETE', "Uuenda paigaldamine on lõppenud.");
define('INSTALL_UPDATE_REFRESH_MAIN_MENU', "värskendada peamenüü.");
// Popup Messages:
define('INSTALL_UPDATE_NEW_VERSION_AVAILABLE', "On uus versioon Breeze Website Builder saadaval. Kas soovite värskendada nüüd? <br /><p class='medium_message' style='text-align:left;'> See teade ilmub iga kord, kui avate Breeze, kuni see on uuendatud. Kui teie Breeze versiooni saab rohkem kui üks versioon aegunud, siis enam neid teateid ja siis on vaja teha täiendavaid uuendusi pooleldi käsitsi. </p>");
define('INSTALL_UPDATE_VERSION_ERROR_ERR', "Üritatakse teha automaatset värskendamist, kuid on olemas erinevuse eelmise versiooni, versiooni faili versiooni ja andmebaasi versiooni.");

///////////////////////// Run SQL /////////////////////////
// Buttons:
define('RUN_SQL_HEADING', "Vii SQL");
// Console Text:
define('RUN_SQL_PASTE_SQL_MSG', "Pasta või sisesta SQL (d) ülaltoodud akent. Siis vajuta &quot;Submit&quot;.");
define('RUN_SQL_SQL_COMMAND_DELIMITERS_NOTE', "Märkus: Iga SQL käsk tuleb lõpetada semikooloniga (;). Ridu, mille alguses (-) või (//) käsitatakse kommentaarid.");

///////////////////////// Javascript Menu Params and Styles /////////////////////////
// Popup Messages:
define('JS_MENU_PARAM_NO_PACAMETERS_1_ERR', "Ei parameetrid on määratud.");
define('JS_MENU_PARAM_NO_PACAMETERS_2_ERR', "tagasi minna ja täitke parameetrid.");
define('JS_MENU_STYLES_ERROR_SAVING_RECORD_ERR', "Viga üritab päästa rekord");
define('JS_MENU_CODE_REMOVE_CODE_CONFIRM_1_MSG', "Kas teie kindel, et soovid eemaldada JavaScript menüüs koodi");
define('JS_MENU_CODE_REMOVE_CODE_CONFIRM_2_MSG', "?");

///////////////////////// Options /////////////////////////
// Strings:
define('OPTIONS_TEMPLATE', "šabloon");
define('OPTIONS_FORCE_PAGE_NAME_TO_LOWER_CASE', "Force Lehekülje nimi väiketähtedesse");
define('OPTIONS_ENABLE_WIZARD', "Luba Wizard");
define('OPTIONS_RUN_WIZARD_LOCAL', "Run Wizard Local (Check ainult siis, kui malli hoidla ja Breeze paigaldus olete samas serveris.)");
define('OPTIONS_ENABLE_FILE_MANAGER_FOR_RESTRICTED_USERS', "Luba failihaldur Piiratud kasutajad");
define('OPTIONS_ACTIVATE_NEW_USERS_AUTOMATICALLY', "Aktiveeri uusi kasutajaid automaatselt");
define('OPTIONS_USE_TABLE_STRUCTURES', "Kasutage tabeli struktuuri");
define('OPTIONS_USE_TABLE_STRUCTURES_ON_MOBILE', "Kasutage tabeli struktuuri mobiili");
define('OPTIONS_CREATE_ACCOUNT_LINK_TEXT', "Loo konto Tekst Link");
define('OPTIONS_LOGIN_LINK_TEXT', "Sisene Tekst Link");
define('OPTIONS_MY_ACCOUNT_LINK_TEXT', "Minu konto Tekst Link");
define('OPTIONS_LOGOUT_LINK_TEXT', "Logi välja lingitekst");
define('OPTIONS_CREATE_ACCOUNT_LINK', "Loo konto Tekst Link");
define('OPTIONS_LOGIN_LINK', "Sisene Tekst Link");
define('OPTIONS_MY_ACCOUNT_LINK', "Minu konto Tekst Link");
define('OPTIONS_LOGOUT_REDIRECT_OVERRIDE', "Logi välja Redirect alistamine");
define('OPTIONS_EDITOR_SOURCE_VIEW_THEME', "Toimetaja Allikas Vaata Theme");
define('OPTIONS_BREEZE_WEBSITE_BUILDER_THEME', "Breeze Website Builder Theme");
define('OPTIONS_LOCKOUT_CLEAR_ALL_CUSTOM_CSS_CLASSES', "Uloslukkiutuminen algoleku CSS klass");
define('OPTIONS_LOCKOUT_COPY_STYLE_SHEET_TO_MOBILE', "Uloslukkiutuminen Copy Style Sheet Mobile");

////////////////////// Manage Custom Fonts /////////////////////////////////////
// Buttons:
define('MANAGE_CUSTOM_FONTS_HEADING', "Manage Kohandatud fondid");
// Console Text:
define('MANAGE_CUSTOM_FONTS_ADD_FONT', "Lisa Font");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT', "Kustuta Font");
define('MANAGE_CUSTOM_FONTS_NO_FONTS', "-Ei kohandatud fonts-");
define('MANAGE_CUSTOM_FONTS_STRETCH', "venitus");
define('MANAGE_CUSTOM_FONTS_STYLE', "stiil");
define('MANAGE_CUSTOM_FONTS_WEIGHT', "kaal");
// Popup Messages:
define('MANAGE_CUSTOM_FONTS_GET_FONTS_MSG', "Kuidas fonte ...");
define('MANAGE_CUSTOM_FONTS_GET_FONTS_COMPLETE_MSG', "Asustamine fonte täielik.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_MSG', "Lisades fondi ...");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_COMPLETE_MSG', "Lisades fondi täielik.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_1_ERR', "font allikas");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_2_ERR', "juba eksisteerib.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_UPLOAD_ERR', "Kahjuks ei olnud viga üleslaadimisel oma kirjas.");
define('MANAGE_CUSTOM_FONTS_ADDING_FONT_FILE_TYPE_ERR', "Vabandame, ainult kulunud aja kauplemissüsteemi, WOFF, WOFF2, SVG ja EOT failid on lubatud.");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_1_MSG', "Oled sa kindel, et soovid kustutada");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_2_MSG', "font allikas");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_CONFIRM_3_MSG', "?");
define('MANAGE_CUSTOM_FONTS_DELETE_FONT_COMPLETE_MSG', "Font kustutatakse.");

////////////////////// Clear All Custom CSS Classes /////////////////////////////////////
// Buttons:
define('CLEAR_CUSTOM_CSS_CLASSES_HEADING', "Clear Custom CSS klass");
// Console Text:
define('CLEAR_CUSTOM_CSS_CLASSES_ALL_STYLE_SHEETS', "Kõik Style Sheets");
// Popup Messages:
define('CLEAR_CUSTOM_CSS_CLASSES_WARNING_MSG', "HOIATUS: enne katset seda operatsiooni sügavalt mõjutada oma kodulehel. See muutus ei saa tagasi võtta. Oled sa kindel, et soovid jätkata?");
define('CLEAR_CUSTOM_CSS_CLASSES_WARNING_2_MSG', "HOIATUS: See operatsioon on mõeldud, et aidata Reseting oma veebilehel või konkreetse plugin või menüü tehaseasendisse. <br /> See muutus ei saa tagasi võtta. See on viimane hoiatus. Kas sa tahad jätkata?");
define('CLEAR_CUSTOM_CSS_CLASSES_START_MSG', "Clearing kohandatud CSS klasse ...");
define('CLEAR_CUSTOM_CSS_CLASSES_COMPLETE_MSG', "Clearing kohandatud CSS klasse lõpetatud.");
define('CLEAR_CUSTOM_CSS_CLASSES_COMPLETE_ERR', "Tekkis viga puhastades kohandatud CSS klasse.");

////////////////////// Backup/Restore /////////////////////////////////////
// Buttons:
define('BACKUP_RESTORE_HEADING', "Varundamine ja taastamine Site");
// Console Text:
define('BACKUP_RESTORE_SELECT_BACKUP', "Valige backup taastada");
define('BACKUP_RESTORE_SELECT_BACKUP_TO_UPLOAD', "Vali Backup soovite taastada arvutist");
define('BACKUP_RESTORE_DELETE_BACKUP', "Kustuta backup");
define('BACKUP_RESTORE_RETAIN_MEDIA', "Merge taastada pilte ja meedia praeguse");
define('BACKUP_RESTORE_UPLOAD_LARGE_BKUPS_MSG', "Üleslaadimine backup faile suurem kui 300 MB võib ebaõnnestuda. Kui see juhtub, FTP varukoopia fail &quot;backup&quot; kausta public_html ja värskendage seda konsooli.");
// Popup Messages:
define('BACKUP_RESTORE_CREATING_BACKUP_PLEASE_WAIT_MSG', "Varundusmeetodid site, palun oota ...");
define('BACKUP_RESTORE_UPLOADING_BACKUP_PLEASE_WAIT_MSG', "Üleslaadimine backup, palun oota ...");
define('BACKUP_RESTORE_RESTORING_WEBSITE', "Taastamine kodulehel .... Leidke alt, kui valmis.");
define('BACKUP_RESTORE_RESTORE_CONFIRM_1_MSG', "Oled sa kindel, et soovid taastada alates");
define('BACKUP_RESTORE_RESTORE_CONFIRM_2_MSG', "backup faili?");
define('BACKUP_RESTORE_DELETE_BACKUP_CONFIRM_MSG', "Oled sa kindel, et soovid kustutada");
define('BACKUP_RESTORE_DELETE_BACKUP_SUCCESS_MSG', "Backup fail on kustutatud.");
define('BACKUP_RESTORE_DELETE_BACKUP_ERROR_ERR', "Tekkis viga kustutades varukoopia.");
define('BACKUP_RESTORE_ERROR_CREATING_FOLDER_ERR', "Loomine ebaõnnestus");
define('BACKUP_RESTORE_ERROR_ERROR_WRITING_FILE_ERR', "Ei saa kirjutada faili");
define('BACKUP_RESTORE_BACKUP_COMPLETE_MSG', "Backup on lõppenud!");
define('BACKUP_RESTORE_BACKUP_READY_FOR_DOWNLOAD_1_MSG', "Teie varu on valmis alla.");
define('BACKUP_RESTORE_BACKUP_READY_FOR_DOWNLOAD_2_MSG', "laadida oma varu.");
define('BACKUP_RESTORE_RETURN_TO_MSG', "naasta Backup / Restore Console");
define('BACKUP_RESTORE_WRONG_FILE_TYPE_1_MSG', "Ainult kokkupakitud failid või gzip faili on lubatud üles laadida, st &quot;backup_54121247.zip&quot; või &quot;backup_54121247.tgz&quot; või &quot;backup_54121247.tar.gz&quot;. Palun kliki");
define('BACKUP_RESTORE_RESTORE_COMPLETE', "Rekon- on lõppenud.");
define('BACKUP_RESTORE_DUMPING_DATABASE', "Dumping andmebaasi ...");
define('BACKUP_RESTORE_ZIPPING_FILES', "Arhiveerides failid ...");



///////////////// Standard words and phrases ///////////////////////
define('WELCOME_WORD', "Tere tulemast");
define('ACCESS_LEVEL_WORD', "Access Level");
define('YES_WORD', "jah");
define('NO_WORD', "ei");
define('SUBMIT_WORD', "Esita");
define('OK_WORD', "Okei");
define('CANCEL_WORD', "tühistama");
define('VERSION_WORD', "versioon");
define('USERID_WORD', "kasutaja ID");
define('USERNAME_WORD', "kasutajanimi");
define('PASSWORD_WORD', "parool");
define('EMAIL_WORD', "E-");
define('NAME_WORD', "kasutajanimi");
define('DASHBOARD_WORD', "armatuurlaud");
define('SAVE_AS_WORD', "Salvesta kui");
define('CREATE_WORD', "looma");
define('UPDATE_WORD', "ajakohastama");
define('REQUIRED_WORD', "nõutud");
define('OPTIONAL_WORD', "vabatahtlik");
define('PLUGINS_WORD', "plugins");
define('RIGHT_WORD', "õige");
define('LEFT_WORD', "vasakule");
define('TOP_WORD', "top");
define('BOTTOM_WORD', "põhi");
define('HEADER_WORD', "päise kaudu");
define('FOOTER_WORD', "jalus");
define('HEAD_WORD', "pea");
define('ERROR_WORD', "viga");
define('ERROR_CAPS_WORD', "VIGA");
define('HERE_WORD', "siin");
define('NEW_WORD', "uus");
define('DESCRIPTION_WORD', "kirjeldus");
define('DATE_WORD', "ajakohastama");
define('LINK_WORD', "link");
define('TARGET_WORD', "sihtmärk");
define('ACTIVE_WORD', "aktiivne");
define('USER_TABLE_WORD', "Kasutaja tabel");
define('HEADER_1ST_CAP_WORD', "Päise");
define('TOP_1ST_CAP_WORD', "top");
define('LEFT_1ST_CAP_WORD', "vasakule");
define('RIGHT_1ST_CAP_WORD', "õige");
define('BOTTOM_1ST_CAP_WORD', "põhi");
define('FOOTER_1ST_CAP_WORD', "jalus");
define('HEAD_1ST_CAP_WORD', "pea");
define('VERTICAL_WORD', "vertikaalne");
define('HORIZONTAL_WORD', "horisontaalne");
define('OFFSET_WORD', "Nihe");
define('POSITION_WORD', "positsioon");
define('POSITIONING_WORD', "positsioneerimine");
define('ABSOLUTE_WORD', "absoluutne");
define('RELATIVE_WORD', "suhteline");
define('WIDTH_WORD', "laius");
define('HEIGHT_WORD', "kõrgus");
define('PROPORTIONAL_WORD', "proportsionaalne");
define('PADDING_WORD', "polster");
define('ORIENTATION_WORD', "orientatsioon");
define('CENTER_WORD', "keskus");
define('JUSTIFY_WORD', "põhjendama");
define('FONT_WORD', "Font");
define('SIZE_WORD', "suurus");
define('WEIGHT_WORD', "kaal");
define('ITALIC_WORD', "kald-");
define('UNDERLINE_WORD', "rõhutama");
define('OVERLINE_WORD', "ülajoon");
define('LINETHROUGH_WORD', "Linethrough");
define('BLINK_WORD', "pilgutama");
define('OBLIQUE_WORD', "kaldus");
define('SHADOW_WORD', "vari");
define('COLOR_WORD', "värv");
define('X_OFFSET_WORD', "X-Nihe");
define('Y_OFFSET_WORD', "Y-nihe");
define('BLUR_WORD', "udu");
define('OPACITY_WORD', "läbipaistmatus");
define('WEBSAFE_WORD', "websafe");
define('NA_WORD', "na");
define('NORMAL_WORD', "normaalne");
define('BOLD_WORD', "Julge");
define('BOLDER_WORD', "Bolder");
define('LIGHTER_WORD', "Heledam");
define('INITIAL_WORD', "esialgne");
define('INHERIT_WORD', "pärima");
define('INITIAL_LC_WORD', "esialgne");
define('INHERIT_LC_WORD', "pärima");
define('RGB_WORD', "#RRGGBB");
define('TEXT_WORD', "tekst");
define('ALIGN_WORD', "joondama");
define('BACKGROUND_WORD', "tagapõhi");
define('BORDER_WORD', "piir");
define('SPREAD_WORD', "levik");
define('INSET_WORD', "vahetükk");
define('BASELINE_WORD', "Baseline");
define('SUB_WORD', "Sub");
define('SUPER_WORD', "Super");
define('MIDDLE_WORD', "kesk-");
define('NONE_WORD', "mitte ükski");
define('RADIUS_WORD', "raadius");
define('MARGIN_WORD', "Marginaal");
define('AUTO_WORD', "auto");
define('DISPLAY_WORD', "ekraan");
define('VISIBILITY_WORD', "nähtavus");
define('OVERFLOW_WORD', "ülevool");
define('FLOAT_WORD', "ujuk");
define('CLIPPING_WORD', "väljalõige");
define('IMAGE_WORD', "pilt");
define('ATTACHMENT_WORD', "kinnitus");
define('REPEAT_WORD', "kordus");
define('LIST_WORD', "nimekiri");
define('TYPE_WORD', "tüüp");
define('FIXED_WORD', "fikseeritud");
define('SCROLL_WORD', "rullraamat");
define('SCROLLING_WORD', "kerimine");
define('INLINE_WORD', "Järjekorras");
define('BLOCK_WORD', "plokk");
define('COMPACT_WORD', "kompaktne");
define('MARKER_WORD', "marker");
define('TABLE_WORD', "Kasutaja tabel");
define('XX_SMALL_WORD', "xx-small");
define('X_SMALL_WORD', "xx-small");
define('SMALL_WORD', "xx-small");
define('MEDIUM_WORD', "keskmine");
define('LARGE_WORD', "suur");
define('X_LARGE_WORD', "x-suur");
define('XX_LARGE_WORD', "xx-suur");
define('SMALLER_WORD', "väiksem");
define('LARGER_WORD', "suurem");
define('NO_WRAP_WORD', "ei Wrap");
define('PRE_WORD', "pre");
define('PRE_LINE_WORD', "Pre-Line");
define('PRE_WRAP_WORD', "Pre-Wrap");
define('POINTER_WORD', "pointer");
define('CROSSHAIR_WORD', "ristikujuline");
define('DEFAULT_WORD', "vaikimisi");
define('WAIT_WORD', "oota");
define('HELP_WORD', "aitama");
define('ALIAS_WORD', "alias");
define('CELL_WORD', "rakk");
define('COPY_WORD', "koopia");
define('RENAME_WORD', "Nimeta");
define('MOVE_WORD', "käik");
define('ASSIGN_WORD', "määrama");
define('PROGRESS_WORD', "edu");
define('HIDDEN_WORD', "varjatud");
define('DOTTED_WORD', "punktiir-");
define('DASHED_WORD', "Kriipsjooni");
define('SOLID_WORD', "tahke");
define('DOUBLE_WORD', "topelt");
define('GROOVE_WORD', "renn");
define('RIDGE_WORD', "kant");
define('OUTSET_WORD', "algusest peale");
define('COLLAPSE_WORD', "kokkuvarisemine");
define('SEPARATE_WORD', "eri");
define('MIN_WORD', "min");
define('MAX_WORD', "max");
define('VISIBLE_WORD', "nähtav");
define('BOTH_WORD', "mõlemad");
define('STATIC_WORD', "staatiline");
define('SCALE_WORD', "skaala");
define('COVER_WORD', "kate");
define('CONTAIN_WORD', "Sisaldama");
define('DISC_WORD', "ketas");
define('CIRCLE_WORD', "ring");
define('SQUARE_WORD', "ruut");
define('DECIMAL_WORD', "kohaga");
define('HEBREW_WORD', "heebrea");
define('ARMENIAN_WORD', "armeenia");
define('GORGIAN_WORD', "gruusia");
define('INSIDE_WORD', "sees");
define('OUTSIDE_WORD', "väljaspool");
define('CLASS_WORD', "klass");
define('SUBCLASS_WORD', "alamklass");
define('ID_WORD', "kasutaja ID");
define('CUSTOM_WORD', "tava");
define('_NONE_WORD', "-none-");
define('ADD_WORD', "Lisama");
define('OWNER_WORD', "omanik");
define('AUTHOR_WORD', "autor");
define('COPYRIGHT_WORD', "autoriõigus");
define('LANGUAGE_WORD', "keel");
define('ABSTRACT_WORD', "Abstraktne");
define('KEYWORDS_WORD', "Märksõnad");
define('SUBJECT_WORD', "teema");
define('ROBOTS_WORD', "Robotid");
define('INDEX_WORD', "indeks");
define('FOLLOW_WORD', "järgima");
define('REVISIT_WORD', "vaadata");
define('DAYS_WORD', "päeva");
define('OR_WORD', "viga");
define('OR_CAP_WORD', "VÕI");
define('TO_WORD', "auto");
define('CLICK_WORD', "Click");
define('PAGE_WORD', "lehekülg");
define('PAGE_1ST_CAP_WORD', "lehekülg");
define('CONTENT_WORD', "sisu");
define('DELETED_WORD', "Kustutatud");
define('BACKUP_WORD', "backup");
define('RESTORE_WORD', "Taastama");
define('REMOVE_WORD', "eemaldama");
define('CLOSE_WORD', "Sulge");
define('INSTALL_WORD', "paigaldama");
define('ADMIN_WORD', "admin");
define('POWER_USER_WORD', "Võimsus Kasutaja");
define('USER_WORD', "Võimsus Kasutaja");
define('RESTRICTED_WORD', "piiratud");
define('BLOGGER_WORD', "Blogger");
define('RECIPIENT_WORD', "saaja");
define('READING_WORD', "lugemine");
define('PARSING_WORD', "parsing");
define('RECALL_WORD', "Tagasikutsumine");
define('OPTION_WORD', "valik");
define('VALUE_WORD', "väärtus");
define('MOBILE_WORD', "mobiilne");
define('TRANSPARENT_WORD', "Läbipaistev");
define('SOURCE_WORD', "allikas");
define('CONDENSED_WORD', "kondenseeritud");
define('ULTRA_CONDENSED_WORD', "Ultra-Kondenspiim");
define('EXTRA_CONDENSED_WORD', "Extra-Kondenspiim");
define('SEMI_WORD', "Semi-Kondenspiim");
define('EXPANDED_WORD', "Expanded");
define('SEMI_EXPANDED_WORD', "Semi-Expanded");
define('EXTRA_EXPANDED_WORD', "Extra-Expanded");
define('ULTRA_EXPANDED_WORD', "Ultra-Expanded");
define('INDENT_WORD', "taane");
define('BUILDING_WORD', "hoone");
define('STYLE_SHEET_WORD', "laadilehte");
define('TITLE_WORD', "pealkiri");
define('REFRESH_WORD', "värskendama");
define('FOLDER_WORD', "kaust");
define('DOWNLOAD_WORD', "Lae alla");

define('QUERY_READY_TO_SEND', "Päringu saatmiseks valmis ...");
define('QUERY_SENT', "Query saata");
define('QUERY_COMPLETE', "Query täielik");
define('QUERY_COMPLETE_NO_RECORD_FOUND', "Päringu täielik. Salvestusi ei leitud.");
define('SELF_NORMAL', "Mina (tavaline)");
define('NEW_WINDOW', "New Window");
define('NAMED_FRAME', "nimega Frame");
define('ENTER_FRAME_NAME', "sisestage raami nimi");
define('TEXT_ALIGNMENT', "tekst viimine");
define('_NOT_SELECTED_', "Oops! Unustasid lehekülje valida ja / või plugin.");
define('_NOT_SET_', "-not set");
define('_NOT_ASSIGNED_', "-not assigned-");
define('LETTER_SPACING', "Tähevahe");
define('SMALL_CAPS', "kapiteelkiri");
define('MOUSE_OUT', "Tavaline (hiir välja)");
define('MOUSE_OVER', "Hover (hiir)");
define('FONT_SIZE', "Font Size");
define('BOX_SHADOW', "Kasti Shadow");
define('BACKGROUND_COLOR', "Top Level Tausta värv");
define('BORDER_COLOR', "Top Level Block Piirdevärvi");
define('BORDER_STYLE', "Piirdestiili");
define('HORIZONTAL_OFFSET', "Rõhtnihe");
define('VERTICAL_OFFSET', "Püstnihe");
define('TEXT_TOP', "tekst Top");
define('TEXT_BOTTOM', "tekst Bottom");
define('VERTICAL_ALIGN', "Vertikaalne joondus");
define('LINE_HEIGHT', "Reakõrgus");
define('SORT_ORDER', "Määra klassi Järjekord");
define('LAST_REVISED', "Viimati täiendatud");
define('GENERATE_PASSWORD', "Loo parool");
define('CHANGE_PASSWORD', "Muuda salasõna");
define('ACCESS_LEVELS', "Muutuvad juurdepääsu taset ...");
define('ADD_USER', "Sa pead valima tabeli esimene lisad kasutaja.");
define('MODIFY_USER', "muuda kasutaja");
define('DELETE_USER', "Oled sa kindel, et soovid eemaldada selle kasutaja");
define('NEW_PASSWORD', "uus salasõna");
define('SELECT_ALL', "Vali kõik");
define('CLEAR_ALL', "Uloslukkiutuminen algoleku CSS klass");
define('TO_TRY_AGAIN', "uuesti proovida.");
define('AND_TRY_AGAIN', "ja proovige uuesti.");
define('NEW_FILE', "uus fail");
define('NEW_FOLDER', "Uus kaust");
define('FOLDER_NAME', "Folder Name");
define('SHOW_BACKUP_FILES', "Näita varukoopiad");
define('EDIT_MENU_ITEMS_MEGA_MENU', "Mega Menu");
define('MEGA_MENU_MANAGE_BTN', "Manage Mega Menüüd");
define('MEGA_MENU_EDIT_SELECT_HEADING', "Manage Mega Menüüd");
define('MEGA_MENU_CREATE_HEADING', "Loo Mega Menu");
define('MEGA_MENU_BACK_BTN', "Tagasi Redigeerimismenüüsse Esemed");
define('MEGA_MENU_PAGE_ALREADY_EXISTS_1_ERR', "Mega menüü");
define('MEGA_MENU_PAGE_ALREADY_EXISTS_2_ERR', "juba eksisteerib. Palun sisesta teise nime või muuta olemasolevat.");
define('MENU_WORD', "menüü");
define('MENU_ITEM', "Menüüvalik");
define('MANAGE_CUSTOM_BORDER_AREA_ADD_AREA_BTN', "Lisa veel piirialal");
define('MANAGE_CUSTOM_BORDER_AREA_BACK_BTN', "Tagasi Manage Piirialade");
define('MANAGE_HEAD_BACK_BTN', "Tagasi Edit Head kood");
define('MANAGE_HEAD_MANAGE_BTN', "Manage Custom Head kood");
define('OPTIONS_ENABLE_CSS_MENUS', "Luba CSS Menüüd");
define('OPTIONS_ENABLE_JS_MENUS', "Luba JavaScript Menüüd");
define('EDITOR_BACK_TO_SELECT', "Tagasi Valige");
define('COPY_STYLE_TO_MOBILE_BACK_TO_EDIT_CSS_SELECT_BTN', "Tagasi Muuda Styles Vali");
define('EDIT_STYLE_SHEET_ATT_BTN', "Manage Style Sheet atribuudid");
define('MANAGE_STYLE_SHEET_ATT_HEADING', "Manage Style Sheet atribuudid");
define('MANAGE_STYLE_SHEET_ATT_BACK_TO_EDIT_CSS_SELECT', "Tagasi Muuda CSS Select");
define('MANAGE_STYLE_SHEET_ATT_CHARSET', "charset");
define('MANAGE_STYLE_SHEET_ATT_IMPORT', "import");
define('MANAGE_STYLE_SHEET_ATT_MEDIA', "andmekandja");
define('MANAGE_STYLE_SHEET_ATT_MEDIA_TYPE', "Media Type");
define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE', "Meedia Feature");
define('MANAGE_STYLE_SHEET_ATT_MEDIA_FEATURE_VALUE', "Meedia Feature Value");
define('MANAGE_STYLE_SHEET_ATT_ADD_STYLE_SHEET', "Lisa Style Sheet");
define('MANAGE_STYLE_SHEET_ATT_DELETE_STYLE_SHEET', "Kustuta Style Sheet");
define('MANAGE_STYLE_SHEET_ATT_RENAME_STYLE_SHEET', "Nimeta stiil Sheet");
define('MANAGE_STYLE_SHEET_ATT_NEW_NAME', "uus nimi");
define('MANAGE_STYLE_SHEET_ATT_NEW_DESC', "uus kirjeldus");
define('MANAGE_STYLE_SHEET_ATT_SAVE_SUCCESS_MSG', "Teie CSS atribuutide on salvestatud.");
define('MANAGE_STYLE_SHEET_ATT_SAVE_ERROR_ERR', "Tekkis viga salvestamata CSS atribuute.");
define('MANAGE_STYLE_SHEET_ATT_ADD_SUCCESS_MSG', "Teie laadilehte on salvestatud.");
define('MANAGE_STYLE_SHEET_ATT_ADD_SHEET_ALREADY_EXISTS_ERR', "See laadilehte juba olemas. Palun valige uus nimi ja proovi uuesti");
define('MANAGE_STYLE_SHEET_ATT_ADD_ERROR_ERR', "Tekkis viga, lisades oma stiilis leht.");
define('MANAGE_STYLE_SHEET_ATT_DELETE_CONFIRM_MSG', "Oled sa kindel, et soovid kustutada");
define('MANAGE_STYLE_SHEET_ATT_DELETE_SUCCESS_MSG', "Teie laadilehte on kustutatud.");
define('MANAGE_STYLE_SHEET_ATT_DELETE_ERROR_ERR', "Tekkis viga kustutada oma stiili lehel.");
define('MANAGE_STYLE_SHEET_ATT_RENAME_SUCCESS_MSG', "Teie laadilehte on ümber.");
define('MANAGE_STYLE_SHEET_ATT_RENAME_ERROR_ERR', "Tekkis viga ümbernimetamine oma stiili lehel.");
define('NOT_WORD', "Mitte");
define('ONLY_WORD', "Ainult");
define('ALL_WORD', "kõik");
define('PRINT_WORD', "trükk");
define('SCREEN_WORD', "ekraan");
define('SPEECH_WORD', "kõne");
define('AND_WORD', "ja");
define('DESKTOP_WORD', "lauaarvuti");
define('MIN_WIDTH', "min Laius");
define('MAX_WIDTH', "max laius");
define('MIN_HEIGHT', "min kõrgus");
define('MAX_HEIGHT', "max kõrgus");
define('GET_MORE_PLUGINS_BTN', "Hankige Plugins");
define('GET_MORE_TEMPLATES_BTN', "Hankige mallid");
define('MANAGE_STYLE_SHEET_ATT_EXCLUDE_FROM_LIST', "Jätta vaikeloendi");
define('MANAGE_STYLE_SHEET_ATT_SHOW_CUSTOM_STYLES', "Kuva kohandatud stiile");
define('MANAGE_STYLE_SHEET_ATT_SHOW_ALL', "Vaata kõiki CSS");
define('UPLOAD_TEMPLATE_UPLOAD_TEMPLATE_COMPLETE', "Mall paigaldamine on lõppenud.");
define('CREATE_PAGE_SELECT_CREATE_PLUGIN_GROUP', "Loo kõik plugin lehekülgi Selle plugina rühm");
define('CREATE_PAGE_SELECT_ALREADY_EXISTS_ERR', "defineerimata");
define('MANAGE_STYLE_SHEET_SET_SORT_ORDER', "Set Style Sheet Järjekord");
define('MANAGE_STYLE_SHEET_NAME_DESCRIPTION', "Style Sheet / Kirjeldus");
define('EDIT_CSS_SHOW_ALL_CLASSES', "Näita kõik klassid");
define('EDIT_CSS_MENU_STYLES_OMIT_ADJACENT_BORDERS', "O&lt;br&gt;m&lt;br&gt;i&lt;br&gt;t&lt;br&gt;&lt;br&gt;A&lt;br&gt;d&lt;br&gt;j&lt;br&gt;a&lt;br&gt;c&lt;br&gt;e&lt;br&gt;n&lt;br&gt;t&lt;br&gt;&lt;br&gt;B&lt;br&gt;o&lt;br&gt;r&lt;br&gt;d&lt;br&gt;e&lt;br&gt;r&lt;br&gt;s");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_1_SIZE_PADDING', "Sub Menüü 1 toode Suurus ja polster");
define('EDIT_CSS_MENU_PARAMETERS_SUB_MENU_2_SIZE_PADDING', "Sub Menüü 2 toode Suurus ja polster");
define('EDIT_CSS_MENU_PARAMETERS_ITEM_SPACING', "Oksjoni Vahed");
define('EDIT_CSS_MENU_STYLES_DOWN', "Alla (nupp alla)");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_BACKGROUND_COLOR', "Sub Level 1 Tausta värv");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_BACKGROUND_COLOR', "defineerimata");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1_ITEM_BORDER_COLOR', "Sub Level 1 punkt Piirdevärvi");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2_ITEM_BORDER_COLOR', "Sub Level 2 Oksjoni Piirdevärvi");
define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_1', "CSS menüü parameetrid ei ole määratud. Palun kliki");
define('EDIT_CSS_MENU_STYLES_PARAMS_NOT_SET_ERR_2', "setup CSS menüüs parameetrite");
define('BORDER_RADIUS', "border Radius");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_1', "Sub Level 1");
define('EDIT_CSS_MENU_STYLES_SUB_LEVEL_2', "Sub Tase 2");
define('EDIT_MENU_ITEMS_ADD_BEFORE_SAVE_NEW_MSG', "Sul on uus toode, mis ei ole salvestatud. Palun salvesta et toode enne lisamist uuega.");
define('EDIT_CSS_MENU_STYLES_SHADOW_COLOR', "Shadow Color");
define('EDIT_CSS_MENU_STYLES_HOVER_ON_DOWN', "Hover Alla");
define('EDIT_CSS_FOREGROUND_OPAQUE_1', "esiplaan");
define('EDIT_CSS_FOREGROUND_OPAQUE_2', "läbipaistmatu");
define('ADMIN_FUNCTION_SELECT_RESTRICT_BLOG_PAGE_EDITING_ACCESS_BTN', "Piira Blog Page redigeerimine Access");
define('RESTRICT_BLOG_EDITING_HEADING', "Piirata juurdepääsu Blogging Bloggers");
define('USERS_WORD', "kasutajad");
define('PUBLISHED_WORD', "avaldatud");
define('DRAFT_WORD', "eelnõu");
define('ADD_ALL', "Lisa kõik");
define('BLOG_PAGE', "Blogi Page");
define('EDIT_CSS_FLEX', "Flex");
define('EDIT_CSS_INLINE_FLEX', "Inline-Flex");
define('EDIT_CSS_CONTENT_TEXT', "sisu tekst");
define('EDIT_CSS_JUSTIFY_CONTENT', "õigustada Sisu");
define('EDIT_CSS_SET_CONTENT_BLANK', "Set Sisu Blank");
define('EDIT_CSS_FLEX_START', "Flex Start");
define('EDIT_CSS_FLEX_END', "Flex End");
define('EDIT_CSS_SPACE_BETWEEN', "vahe");
define('EDIT_CSS_SPACE_AROUND', "space Around");
define('EDIT_CSS_SET_DISPLAY_FLEX', "Määra Display Flex");
define('EDIT_CSS_WRAP_REVERSE', "wrap Reverse");
define('EDIT_CSS_ROW_REVERSE', "Row Reverse");
define('EDIT_CSS_COLUMN_REVERSE', "defineerimata");
define('EDIT_CSS_DISPLAY_SET_TO_FLEX', "Ekraan atribuut on seatud &quot;flex&quot;.");
define('EDIT_CSS_CONTENT_SET_TO_BLANK', "String &quot;-blank-&quot; ütleb CSS string compliler määrata sisu &#39;&#39;.");
define('WRAP_WORD', "wrap");
define('CAPITALIZE_WORD', "kapitaliseerima");
define('UPPERCASE_WORD', "suur-");
define('LOWERCASE_WORD', "väiketähed");
define('STRING_WORD', "nöör");
define('ATTRIBUTE_WORD', "Atribuut");
define('COUNTER_WORD', "loendaja");
define('TRANSITION_WORD', "üleminek");
define('PROPERTY_WORD', "vara");
define('DURATION_WORD', "Duration");
define('DELAY_WORD', "viivitus");
define('EASE_WORD', "kergendama");
define('LINEAR_WORD', "lineaarne");
define('BASIS_WORD', "Alus");
define('GROW_WORD', "kasvama");
define('SHRINK_WORD', "kahaneb");
define('LENGTH_WORD', "pikkus");
define('DIRECTION_WORD', "suund");
define('ROW_WORD', "rida");
define('COLUMN_WORD', "Veerg");
define('TEXT_TRANSFORM', "tekst Transform");
define('OPEN_QUOTE', "Open Quote");
define('CLOSE_QUOTE', "Sulge Quote");
define('NO_OPEN_QUOTE', "Nr Open Quote");
define('NO_CLOSE_QUOTE', "Nr Sulge Quote");
define('TIMING_FUNCTION', "taimerifunktsioon");
define('EASE_IN', "Sissesulatus");
define('EASE_OUT', "Lihtne Out");
define('EASE_IN_OUT', "Sisse- ja väljasulatus");
define('WIDTH_AND_HEIGHT', "Laius ja Kõrgus");
define('EDIT_CSS_ENTER_STR_MSG', "Sisestage teksti kasutada sisult sisu tekstisisestusväljal või jäta tühjaks määrata teksti tühjaks.");
define('EDIT_CSS_ENTER_URL_MSG', "Sisestage URL Sisu Tekst väljale.");
define('EDIT_CSS_ENTER_ATTR_MSG', "Sisestage HTML objekti attribite ehk &quot;href&quot; või &quot;nime&quot; muutmine Sisu Tekst väljale.");
define('IMPORTANT_HEADING', "Oluliste CSS-atribuutide haldamine");
define('MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR', "Tabelis puuduvad kasutajanime väljad. Kui soovite kasutada seda tabelit kasutajate juurdepääsu jaoks, peate kõigepealt lisama sellele tabele kasutajanime väljad, kasutades nuppu &quot;Lisa kasutajanime väli tabelisse&quot;.");
define('THRU_WORD', "läbi");
define('OF_WORD', "Of");
define('SHOWING_RECORDS', "Näita rekordeid");
define('FIRST_NAME', "Eesnimi");
define('LAST_NAME', "Perekonnanimi");
define('EDIT_CSS_MENU_PARAMETERS_LATCH_EXPANDED_ON_DOWN', "Latch Expanded Subs on item down");
define('RADIAL_WORD', "Radiaal");
define('ANGLE_WORD', "Nurk");
define('DEGREES_WORD', "Kraadid");
define('BACKGROUND_GRADIENT', "Taust Gradient");
define('TOP_TO_BOTTOM', "Ülevalt alla");
define('BOTTOM_LEFT_TO_TOP_RIGHT', "Alt vasakult paremale");
define('LEFT_TO_RIGHT', "Left to Right");
define('TOP_LEFT_TO_BOTTOM_RIGHT', "Ülemine vasakule alt paremale");
define('BOTTOM_TO_TOP', "Alt ülespoole");
define('TOP_RIGHT_TO_BOTTOM_LEFT', "Paremale vasakule vasakule");
define('RIGHT_TO_LEFT', "Parem vasakule");
define('BOTTOM_RIGHT_TO_TOP_LEFT', "Alt paremal ülespoole vasakule");
define('EDIT_CSS_MENU_PARAMETERS_SUB_1_MENU_POSITIONING', "Alammenüü 1 paigutus ja positsioneerimine");
define('EDIT_CSS_MENU_PARAMETERS_SUB_2_MENU_POSITIONING', "Alammenüü 2 paigutus ja positsioneerimine");
define('HOVER_WORD', "Hõljuma");
define('DOWN_WORD', "Alla");
define('EDIT_CSS_MENU_PARAMETERS_BASE_Z_INDEX', "Baas Z-Index");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1', "Selles kategoorias pole ühtegi plugina");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2', "Kliki");
define('CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3', "selle kategooria plugina leidmiseks.");
define('MAIN_MENU_MANAGE_MY_ACCOUNT_BTN', "Minu konto haldamine");
define('MAIN_MENU_SHOW_PASSWORD_RESET_MSG', "Teie parooli on ajakohastatud ajutise parooliga. Soovitatav on muuta oma salasõna, et somethitngit hõlpsamini sisestada ja meelde jätta, ning seejärel salvestage uus parool turvalises kohas. Kas soovite oma parooli kohe muuta?");
define('MANAGE_USERS_CHANGE_MY_PASSWORD', "Muuda minu parooli");
define('MANAGE_USERS_MODIFY_MY_ACCOUNT', "Muuda minu kontot");
define('STICKY_WORD', "Kleepuv");
define('EDIT_CSS_SETUP_STICKY_HEADER_BTN', "Kleepuva päise seadistamine");
define('EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG', "Nüüd laadime stiile sätted, mis paneb teie veebilehtede päise oma brauseriakna ülaosas kinni.");
define('EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG', "Teie päis jääb nüüd brauseriakna ülaossa.");
define('UPLOAD_TEMPLATE_COPYING_FONTS_MSG', "Fontide kopeerimine ...");
define('MANAGE_MENUS_COPY_MENU_BTN', "Kopeeri menüü");
define('MANAGE_MENUS_COPY_MENU_ITEMS_TO_MOBILE_BTN', "Kopeeri töölauamenüü üksused mobiilseadmesse");
define('MANAGE_MENUS_CREATE_NEW', "Uus menüü");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_1_MSG', "Kas olete kindel, et soovite selle kopeerida");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_2_MSG', "menüüst");
define('MANAGE_MENUS_COPY_MENU_CONFIRM_3_MSG', "menüü?");
define('MANAGE_MENUS_COPY_MENU_ITEMS_CONFIRM_2_MSG', "menüüelemendid");
define('TO_1ST_CAP_WORD', "Et");
define('FROM_WORD', "Alates");
?>